import logging
from collections.abc import Mapping, Sequence
from typing import IO, ClassVar, TypedDict

from .util import Context

logger: logging.Logger

class KeyValues(dict[str, str]):
    parser_attr: ClassVar[str | None]
    parser: DockerfileParser
    def __init__(self, key_values: Mapping[str, str], parser: DockerfileParser) -> None: ...
    def __delitem__(self, key: str) -> None: ...
    def __setitem__(self, key: str, value: str) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...  # type: ignore[override]

class Labels(KeyValues): ...
class Envs(KeyValues): ...
class Args(KeyValues): ...

class _InstructionDict(TypedDict):
    instruction: str
    startline: int
    endline: int
    content: str
    value: str

class DockerfileParser:
    fileobj: IO[str]
    dockerfile_path: str
    cache_content: bool
    cached_content: str
    env_replace: bool
    parent_env: dict[str, str]
    build_args: dict[str, str]
    def __init__(
        self,
        path: str | None = None,
        cache_content: bool = False,
        env_replace: bool = True,
        parent_env: dict[str, str] | None = None,
        fileobj: IO[str] | None = None,
        build_args: dict[str, str] | None = None,
    ) -> None: ...
    lines: list[str]
    content: str
    @property
    def structure(self) -> list[_InstructionDict]: ...
    @property
    def json(self) -> str: ...
    parent_images: Sequence[str]
    @property
    def is_multistage(self) -> bool: ...
    baseimage: str
    cmd: str
    labels: Mapping[str, str]
    envs: Mapping[str, str]
    args: Mapping[str, str]
    def add_lines(
        self, *lines: str, all_stages: bool | None = ..., at_start: bool | None = ..., skip_scratch: bool | None = ...
    ) -> None: ...
    def add_lines_at(
        self, anchor: str | int | dict[str, int], *lines: str, replace: bool | None = ..., after: bool | None = ...
    ) -> None: ...
    @property
    def context_structure(self) -> list[Context]: ...

def image_from(from_value: str) -> tuple[str | None, str | None]: ...



from typing import Any, ClassVar, Literal, TypedDict, type_check_only

from .drawing import DeviceGray, DeviceRGB
from .enums import TextMode
from .fonts import FontFace

@type_check_only
class _TextShaping(TypedDict):
    use_shaping_engine: bool
    features: dict[str, bool]
    direction: Literal["ltr", "rtl"]
    script: str | None
    language: str | None
    fragment_direction: Literal["L", "R"] | None
    paragraph_direction: Literal["L", "R"] | None

class GraphicsStateMixin:
    DEFAULT_DRAW_COLOR: ClassVar[DeviceGray]
    DEFAULT_FILL_COLOR: ClassVar[DeviceGray]
    DEFAULT_TEXT_COLOR: ClassVar[DeviceGray]
    def __init__(self, *args, **kwargs) -> None: ...
    @property
    def draw_color(self) -> DeviceGray | DeviceRGB: ...
    @draw_color.setter
    def draw_color(self, v: DeviceGray | DeviceRGB) -> None: ...
    @property
    def fill_color(self) -> DeviceGray | DeviceRGB: ...
    @fill_color.setter
    def fill_color(self, v: DeviceGray | DeviceRGB) -> None: ...
    @property
    def text_color(self) -> DeviceGray | DeviceRGB: ...
    @text_color.setter
    def text_color(self, v: DeviceGray | DeviceRGB) -> None: ...
    @property
    def underline(self) -> bool: ...
    @underline.setter
    def underline(self, v: bool) -> None: ...
    @property
    def font_style(self) -> str: ...
    @font_style.setter
    def font_style(self, v: str) -> None: ...
    @property
    def font_stretching(self) -> float: ...
    @font_stretching.setter
    def font_stretching(self, v: float) -> None: ...
    @property
    def char_spacing(self) -> float: ...
    @char_spacing.setter
    def char_spacing(self, v: float) -> None: ...
    @property
    def font_family(self) -> str: ...
    @font_family.setter
    def font_family(self, v: str) -> None: ...
    @property
    def font_size_pt(self) -> float: ...
    @font_size_pt.setter
    def font_size_pt(self, v: float) -> None: ...
    @property
    def font_size(self) -> float: ...
    @font_size.setter
    def font_size(self, v: float) -> None: ...
    @property
    def current_font(self) -> dict[str, Any]: ...
    @current_font.setter
    def current_font(self, v: dict[str, Any]) -> None: ...
    @property
    def dash_pattern(self) -> dict[str, float]: ...
    @dash_pattern.setter
    def dash_pattern(self, v: dict[str, float]) -> None: ...
    @property
    def line_width(self) -> float: ...
    @line_width.setter
    def line_width(self, v: float) -> None: ...
    @property
    def text_mode(self) -> TextMode: ...
    @text_mode.setter
    def text_mode(self, v: int | str) -> None: ...
    @property
    def char_vpos(self): ...
    @char_vpos.setter
    def char_vpos(self, v) -> None: ...
    @property
    def sub_scale(self): ...
    @sub_scale.setter
    def sub_scale(self, v) -> None: ...
    @property
    def sup_scale(self): ...
    @sup_scale.setter
    def sup_scale(self, v) -> None: ...
    @property
    def nom_scale(self): ...
    @nom_scale.setter
    def nom_scale(self, v) -> None: ...
    @property
    def denom_scale(self): ...
    @denom_scale.setter
    def denom_scale(self, v) -> None: ...
    @property
    def sub_lift(self): ...
    @sub_lift.setter
    def sub_lift(self, v) -> None: ...
    @property
    def sup_lift(self): ...
    @sup_lift.setter
    def sup_lift(self, v) -> None: ...
    @property
    def nom_lift(self): ...
    @nom_lift.setter
    def nom_lift(self, v) -> None: ...
    @property
    def denom_lift(self): ...
    @denom_lift.setter
    def denom_lift(self, v) -> None: ...
    @property
    def text_shaping(self) -> _TextShaping | None: ...
    @text_shaping.setter
    def text_shaping(self, v: _TextShaping | None) -> None: ...
    def font_face(self) -> FontFace: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import ChineseNewYearCalendar

class SouthKorea(ChineseNewYearCalendar):
    FIXED_HOLIDAYS: Incomplete
    chinese_new_year_label: ClassVar[str]
    include_chinese_new_year_eve: ClassVar[bool]
    chinese_new_year_eve_label: ClassVar[str]
    include_chinese_second_day: ClassVar[bool]
    chinese_second_day_label: ClassVar[str]
    def get_variable_days(self, year): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def laplacian_centrality(
    G,
    normalized: bool = True,
    nodelist: Incomplete | None = None,
    weight: str = "weight",
    walk_type: Incomplete | None = None,
    alpha: float = 0.95,
): ...



from _typeshed import Incomplete
from dataclasses import dataclass
from io import BytesIO
from logging import Logger
from types import TracebackType
from typing import Any, Literal
from typing_extensions import TypeAlias

from PIL import Image

from .image_datastructures import ImageCache, ImageInfo, VectorImageInfo
from .svg import SVGObject

_ImageFilter: TypeAlias = Literal["AUTO", "FlateDecode", "DCTDecode", "JPXDecode"]

RESAMPLE: Image.Resampling

@dataclass
class ImageSettings:
    compression_level: int = -1

LOGGER: Logger
SUPPORTED_IMAGE_FILTERS: tuple[_ImageFilter, ...]
SETTINGS: ImageSettings

TIFFBitRevTable: list[int]

def preload_image(
    image_cache: ImageCache, name: str | BytesIO | Image.Image, dims: tuple[float, float] | None = None
) -> tuple[str, BytesIO | Image.Image | None, ImageInfo]: ...
def load_image(filename): ...
def is_iccp_valid(iccp, filename) -> bool: ...
def get_svg_info(filename: str, img: BytesIO, image_cache: ImageCache) -> tuple[str, SVGObject, VectorImageInfo]: ...

# Returned dict could be typed as a TypedDict.
def get_img_info(
    filename, img: BytesIO | Image.Image | None = None, image_filter: _ImageFilter = "AUTO", dims: Incomplete | None = None
) -> dict[str, Any]: ...

class temp_attr:
    obj: Any
    field: str
    value: Any
    exists: bool  # defined after __enter__ is called
    def __init__(self, obj: Any, field: str, value: Any) -> None: ...
    def __enter__(self) -> None: ...
    def __exit__(
        self, exctype: type[BaseException] | None, excinst: BaseException | None, exctb: TracebackType | None
    ) -> None: ...

def ccitt_payload_location_from_pil(img: Image.Image) -> tuple[int, int]: ...
def transcode_monochrome(img: Image.Image): ...



from _typeshed import Incomplete

class SettlementBatchSummaryGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def generate(self, settlement_date, group_by_custom_field: Incomplete | None = None): ...



from _typeshed import Incomplete

class ErrorListener:
    def syntaxError(self, recognizer, offendingSymbol, line, column, msg, e) -> None: ...
    def reportAmbiguity(self, recognizer, dfa, startIndex, stopIndex, exact, ambigAlts, configs) -> None: ...
    def reportAttemptingFullContext(self, recognizer, dfa, startIndex, stopIndex, conflictingAlts, configs) -> None: ...
    def reportContextSensitivity(self, recognizer, dfa, startIndex, stopIndex, prediction, configs) -> None: ...

class ConsoleErrorListener(ErrorListener):
    INSTANCE: Incomplete
    def syntaxError(self, recognizer, offendingSymbol, line, column, msg, e) -> None: ...

class ProxyErrorListener(ErrorListener):
    delegates: Incomplete
    def __init__(self, delegates) -> None: ...
    def syntaxError(self, recognizer, offendingSymbol, line, column, msg, e) -> None: ...
    def reportAmbiguity(self, recognizer, dfa, startIndex, stopIndex, exact, ambigAlts, configs) -> None: ...
    def reportAttemptingFullContext(self, recognizer, dfa, startIndex, stopIndex, conflictingAlts, configs) -> None: ...
    def reportContextSensitivity(self, recognizer, dfa, startIndex, stopIndex, prediction, configs) -> None: ...



class InvalidSamplingManifestError(Exception): ...
class SegmentNotFoundException(Exception): ...
class InvalidDaemonAddressException(Exception): ...
class SegmentNameMissingException(Exception): ...
class SubsegmentNameMissingException(Exception): ...
class FacadeSegmentMutationException(Exception): ...
class MissingPluginNames(Exception): ...
class AlreadyEndedException(Exception): ...



from _typeshed import Incomplete
from typing import Any

class _PasslibRegistryProxy:
    __name__: str
    __package__: Any
    def __getattr__(self, attr: str): ...
    def __setattr__(self, attr: str, value) -> None: ...
    def __dir__(self): ...

def register_crypt_handler_path(name, path) -> None: ...
def register_crypt_handler(handler, force: bool = False, _attr: Incomplete | None = None) -> None: ...
def get_crypt_handler(name, default=...): ...
def list_crypt_handlers(loaded_only: bool = False): ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Malta(WesternCalendar):
    include_good_friday: ClassVar[bool]
    include_assumption: ClassVar[bool]
    include_immaculate_conception: ClassVar[bool]
    include_christmas: ClassVar[bool]
    include_labour_day: ClassVar[bool]
    labour_day_label: ClassVar[str]
    FIXED_HOLIDAYS: Incomplete



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Colombia(WesternCalendar):
    FIXED_HOLIDAYS: Incomplete
    include_labour_day: ClassVar[bool]
    include_palm_sunday: ClassVar[bool]
    include_holy_thursday: ClassVar[bool]
    include_good_friday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    include_corpus_christi: ClassVar[bool]
    include_immaculate_conception: ClassVar[bool]
    def get_epiphany(self, year): ...
    def get_saint_joseph(self, year): ...
    def get_ascension(self, year): ...
    def get_corpus_christi(self, year): ...
    def get_sacred_heart(self, year): ...
    def get_saint_peter_and_saint_paul(self, year): ...
    def get_assumption(self, year): ...
    def get_day_of_the_races(self, year): ...
    def get_all_saints(self, year): ...
    def get_cartagena_independence(self, year): ...
    def get_variable_days(self, year): ...



from _typeshed import SupportsItems
from collections.abc import Iterable, Iterator
from typing import Any, Protocol, TypeVar

_KT_co = TypeVar("_KT_co", covariant=True)
_VT_co = TypeVar("_VT_co", covariant=True)
_T = TypeVar("_T")

class _SupportsItemsAndLen(SupportsItems[_KT_co, _VT_co], Protocol[_KT_co, _VT_co]):
    def __len__(self) -> int: ...

class CircularDependencyError(ValueError):
    data: dict[Any, set[Any]]
    def __init__(self, data: dict[Any, set[Any]]) -> None: ...

def toposort(data: _SupportsItemsAndLen[_T, Iterable[_T]]) -> Iterator[set[_T]]: ...
def toposort_flatten(data: _SupportsItemsAndLen[_T, Iterable[_T]], sort: bool = ...) -> list[_T]: ...



from _typeshed import Incomplete
from typing import NoReturn

from stripe.api_resources.abstract import UpdateableAPIResource as UpdateableAPIResource
from stripe.api_resources.account import Account as Account

class Capability(UpdateableAPIResource):
    OBJECT_NAME: str
    def instance_url(self) -> str: ...
    @classmethod
    def modify(cls, sid, **params) -> NoReturn: ...
    @classmethod
    def retrieve(cls, id, api_key: Incomplete | None = None, **params) -> NoReturn: ...



from typing import Any

from . import base

class Filter(base.Filter):
    allowed_elements: Any
    allowed_attributes: Any
    allowed_css_properties: Any
    allowed_css_keywords: Any
    allowed_svg_properties: Any
    allowed_protocols: Any
    allowed_content_types: Any
    attr_val_is_uri: Any
    svg_attr_val_allows_ref: Any
    svg_allow_local_href: Any
    def __init__(
        self,
        source,
        allowed_elements=...,
        allowed_attributes=...,
        allowed_css_properties=...,
        allowed_css_keywords=...,
        allowed_svg_properties=...,
        allowed_protocols=...,
        allowed_content_types=...,
        attr_val_is_uri=...,
        svg_attr_val_allows_ref=...,
        svg_allow_local_href=...,
    ) -> None: ...
    def __iter__(self): ...
    def sanitize_token(self, token): ...
    def allowed_token(self, token): ...
    def disallowed_token(self, token): ...
    def sanitize_css(self, style): ...



from hvac.api.vault_api_base import VaultApiBase

class Cert(VaultApiBase):
    def create_ca_certificate_role(
        self,
        name,
        certificate: str = "",
        certificate_file: str = "",
        allowed_common_names: str = "",
        allowed_dns_sans: str = "",
        allowed_email_sans: str = "",
        allowed_uri_sans: str = "",
        allowed_organizational_units: str = "",
        required_extensions: str = "",
        display_name: str = "",
        token_ttl: int = 0,
        token_max_ttl: int = 0,
        token_policies=[],
        token_bound_cidrs=[],
        token_explicit_max_ttl: int = 0,
        token_no_default_policy: bool = False,
        token_num_uses: int = 0,
        token_period: int = 0,
        token_type: str = "",
        mount_point: str = "cert",
    ): ...
    def read_ca_certificate_role(self, name, mount_point: str = "cert"): ...
    def list_certificate_roles(self, mount_point: str = "cert"): ...
    def delete_certificate_role(self, name, mount_point: str = "cert"): ...
    def configure_tls_certificate(self, mount_point: str = "cert", disable_binding: bool = False): ...
    def login(
        self,
        name: str = "",
        cacert: bool = False,
        cert_pem: str = "",
        key_pem: str = "",
        mount_point: str = "cert",
        use_token: bool = True,
    ): ...

    class CertificateAuthError(Exception): ...



from _typeshed import Incomplete

from braintree.bin_data import BinData
from braintree.resource import Resource
from braintree.three_d_secure_info import ThreeDSecureInfo

class PaymentMethodNonce(Resource):
    @staticmethod
    def create(payment_method_token, params={}): ...
    @staticmethod
    def find(payment_method_nonce): ...
    three_d_secure_info: ThreeDSecureInfo | None
    authentication_insight: Incomplete
    bin_data: BinData
    def __init__(self, gateway, attributes) -> None: ...



from _typeshed import Incomplete

class SignatureService:
    private_key: Incomplete
    hmac_hash: Incomplete
    def __init__(self, private_key, hashfunc=...) -> None: ...
    def sign(self, data): ...
    def hash(self, data): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def randomized_partitioning(G, seed: Incomplete | None = None, p: float = 0.5, weight: Incomplete | None = None): ...
@_dispatch
def one_exchange(G, initial_cut: Incomplete | None = None, seed: Incomplete | None = None, weight: Incomplete | None = None): ...



from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Policies(SystemBackendMixin):
    def list_acl_policies(self): ...
    def read_acl_policy(self, name): ...
    def create_or_update_acl_policy(self, name, policy, pretty_print: bool = True): ...
    def delete_acl_policy(self, name): ...
    def list_rgp_policies(self): ...
    def read_rgp_policy(self, name): ...
    def create_or_update_rgp_policy(self, name, policy, enforcement_level): ...
    def delete_rgp_policy(self, name): ...
    def list_egp_policies(self): ...
    def read_egp_policy(self, name): ...
    def create_or_update_egp_policy(self, name, policy, enforcement_level, paths): ...
    def delete_egp_policy(self, name): ...



from _typeshed import Incomplete

class BuilderConfigAggregateWindow:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, period: Incomplete | None = None, fill_values: Incomplete | None = None) -> None: ...
    @property
    def period(self): ...
    @period.setter
    def period(self, period) -> None: ...
    @property
    def fill_values(self): ...
    @fill_values.setter
    def fill_values(self, fill_values) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



# Stubs-only module with type aliases for ExifRead.

from typing import Any, Literal, Protocol
from typing_extensions import TypeAlias

# The second item of the value tuple - if it exists - can be a variety of types,
# including a callable or another dict.
TagDict: TypeAlias = dict[int, tuple[str] | tuple[str, Any]]

class Reader(Protocol):
    def __iter__(self) -> bytes: ...
    def read(self, size: int, /) -> bytes: ...
    def tell(self) -> int: ...
    def seek(self, offset: int, whence: Literal[0, 1] = ..., /) -> object: ...



def getSortKey(component): ...
def sortByUID(components): ...
def deleteExtraneous(component, ignore_dtstamp: bool = False) -> None: ...
def diff(left, right): ...
def prettyDiff(leftObj, rightObj) -> None: ...
def main() -> None: ...

version: str

def getOptions(): ...



from _typeshed import Incomplete

def draw(G, pos: Incomplete | None = None, ax: Incomplete | None = None, **kwds) -> None: ...
def draw_networkx(
    G, pos: Incomplete | None = None, arrows: Incomplete | None = None, with_labels: bool = True, **kwds
) -> None: ...
def draw_networkx_nodes(
    G,
    pos,
    nodelist: Incomplete | None = None,
    node_size: Incomplete | int = 300,
    node_color: str = "#1f78b4",
    node_shape: str = "o",
    alpha: Incomplete | None = None,
    cmap: Incomplete | None = None,
    vmin: Incomplete | None = None,
    vmax: Incomplete | None = None,
    ax: Incomplete | None = None,
    linewidths: Incomplete | None = None,
    edgecolors: Incomplete | None = None,
    label: Incomplete | None = None,
    margins: Incomplete | None = None,
): ...
def draw_networkx_edges(
    G,
    pos,
    edgelist: Incomplete | None = None,
    width: float = 1.0,
    edge_color: str = "k",
    style: str = "solid",
    alpha: Incomplete | None = None,
    arrowstyle: Incomplete | None = None,
    arrowsize: int = 10,
    edge_cmap: Incomplete | None = None,
    edge_vmin: Incomplete | None = None,
    edge_vmax: Incomplete | None = None,
    ax: Incomplete | None = None,
    arrows: Incomplete | None = None,
    label: Incomplete | None = None,
    node_size: Incomplete | int = 300,
    nodelist: Incomplete | None = None,
    node_shape: str = "o",
    connectionstyle: str = "arc3",
    min_source_margin: int = 0,
    min_target_margin: int = 0,
): ...
def draw_networkx_labels(
    G,
    pos,
    labels: Incomplete | None = None,
    font_size: int = 12,
    font_color: str = "k",
    font_family: str = "sans-serif",
    font_weight: str = "normal",
    alpha: Incomplete | None = None,
    bbox: Incomplete | None = None,
    horizontalalignment: str = "center",
    verticalalignment: str = "center",
    ax: Incomplete | None = None,
    clip_on: bool = True,
): ...
def draw_networkx_edge_labels(
    G,
    pos,
    edge_labels: Incomplete | None = None,
    label_pos: float = 0.5,
    font_size: int = 10,
    font_color: str = "k",
    font_family: str = "sans-serif",
    font_weight: str = "normal",
    alpha: Incomplete | None = None,
    bbox: Incomplete | None = None,
    horizontalalignment: str = "center",
    verticalalignment: str = "center",
    ax: Incomplete | None = None,
    rotate: bool = True,
    clip_on: bool = True,
): ...
def draw_circular(G, **kwargs) -> None: ...
def draw_kamada_kawai(G, **kwargs) -> None: ...
def draw_random(G, **kwargs) -> None: ...
def draw_spectral(G, **kwargs) -> None: ...
def draw_spring(G, **kwargs) -> None: ...
def draw_shell(G, nlist: Incomplete | None = None, **kwargs) -> None: ...
def draw_planar(G, **kwargs) -> None: ...



from _typeshed import Incomplete

from braintree.resource import Resource

class GrantedPaymentInstrumentUpdate(Resource):
    payment_method_nonce: Incomplete
    def __init__(self, gateway, attributes) -> None: ...



from _typeshed import Incomplete

class TemplateKind:
    BUCKET: str
    CHECK: str
    CHECKDEADMAN: str
    CHECKTHRESHOLD: str
    DASHBOARD: str
    LABEL: str
    NOTIFICATIONENDPOINT: str
    NOTIFICATIONENDPOINTHTTP: str
    NOTIFICATIONENDPOINTPAGERDUTY: str
    NOTIFICATIONENDPOINTSLACK: str
    NOTIFICATIONRULE: str
    TASK: str
    TELEGRAF: str
    VARIABLE: str
    openapi_types: Incomplete
    attribute_map: Incomplete
    def __init__(self) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from typing import Any

from .authorization import AuthorizationEndpoint as AuthorizationEndpoint
from .introspect import IntrospectEndpoint as IntrospectEndpoint
from .resource import ResourceEndpoint as ResourceEndpoint
from .revocation import RevocationEndpoint as RevocationEndpoint
from .token import TokenEndpoint as TokenEndpoint

class Server(AuthorizationEndpoint, IntrospectEndpoint, TokenEndpoint, ResourceEndpoint, RevocationEndpoint):
    auth_grant: Any
    implicit_grant: Any
    password_grant: Any
    credentials_grant: Any
    refresh_grant: Any
    bearer: Any
    def __init__(
        self,
        request_validator,
        token_expires_in: Incomplete | None = None,
        token_generator: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
        *args,
        **kwargs,
    ) -> None: ...

class WebApplicationServer(AuthorizationEndpoint, IntrospectEndpoint, TokenEndpoint, ResourceEndpoint, RevocationEndpoint):
    auth_grant: Any
    refresh_grant: Any
    bearer: Any
    def __init__(
        self,
        request_validator,
        token_generator: Incomplete | None = None,
        token_expires_in: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
        **kwargs,
    ) -> None: ...

class MobileApplicationServer(AuthorizationEndpoint, IntrospectEndpoint, ResourceEndpoint, RevocationEndpoint):
    implicit_grant: Any
    bearer: Any
    def __init__(
        self,
        request_validator,
        token_generator: Incomplete | None = None,
        token_expires_in: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
        **kwargs,
    ) -> None: ...

class LegacyApplicationServer(TokenEndpoint, IntrospectEndpoint, ResourceEndpoint, RevocationEndpoint):
    password_grant: Any
    refresh_grant: Any
    bearer: Any
    def __init__(
        self,
        request_validator,
        token_generator: Incomplete | None = None,
        token_expires_in: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
        **kwargs,
    ) -> None: ...

class BackendApplicationServer(TokenEndpoint, IntrospectEndpoint, ResourceEndpoint, RevocationEndpoint):
    credentials_grant: Any
    bearer: Any
    def __init__(
        self,
        request_validator,
        token_generator: Incomplete | None = None,
        token_expires_in: Incomplete | None = None,
        refresh_token_generator: Incomplete | None = None,
        **kwargs,
    ) -> None: ...



from _typeshed import Incomplete
from collections.abc import Callable, Hashable, Mapping
from typing_extensions import Concatenate, ParamSpec, TypeAlias

from numpy import ufunc
from pandas import DataFrame

# pandas._typing.AggFuncTypeFrame is partially Unknown
_AggFuncTypeBase: TypeAlias = Callable[..., Incomplete] | str | ufunc
# Using Hashable instead of HashableT to work around pytype issue
_AggFuncTypeDictFrame: TypeAlias = Mapping[Hashable, _AggFuncTypeBase | list[_AggFuncTypeBase]]
_AggFuncTypeFrame: TypeAlias = _AggFuncTypeBase | list[_AggFuncTypeBase] | _AggFuncTypeDictFrame

_P = ParamSpec("_P")

class GroupBy:
    order: dict[str, list[Incomplete] | None]
    def __init__(self, order: list[str] | dict[str, list[Incomplete] | None]) -> None: ...
    # Signature based on pandas.core.groupby.generic.DataFrameGroupBy.aggregate
    # args and kwargs possible values depend on func which itself can be
    # an attribute name, a mapping, a callable, or lead to a jitted numba function
    def agg(
        self,
        data: DataFrame,
        func: _AggFuncTypeFrame = ...,
        *args: Incomplete,
        engine: str | None = None,
        engine_kwargs: dict[str, bool] | None = None,
        **kwargs: Incomplete,
    ) -> DataFrame: ...
    def apply(
        self, data: DataFrame, func: Callable[Concatenate[DataFrame, _P], DataFrame], *args: _P.args, **kwargs: _P.kwargs
    ) -> DataFrame: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def closeness_centrality(G, u: Incomplete | None = None, distance: Incomplete | None = None, wf_improved: bool = True): ...
@_dispatch
def incremental_closeness_centrality(
    G, edge, prev_cc: Incomplete | None = None, insertion: bool = True, wf_improved: bool = True
): ...



from _typeshed import Incomplete
from typing_extensions import TypeAlias

from networkx.classes.graph import Graph, _Node
from networkx.classes.multidigraph import MultiDiGraph

_MultiEdge: TypeAlias = tuple[_Node, _Node, int]  # noqa: Y047

class MultiGraph(Graph[_Node]):
    def __init__(self, incoming_graph_data: Incomplete | None = None, multigraph_input: bool | None = None, **attr) -> None: ...
    def new_edge_key(self, u: _Node, v: _Node) -> int: ...
    def add_edge(self, u_for_edge, v_for_edge, key: Incomplete | None = None, **attr): ...  # type: ignore[override]  # Has an additional `key` keyword argument
    def remove_edge(self, u, v, key: Incomplete | None = None): ...
    def has_edge(self, u, v, key: Incomplete | None = None): ...
    def get_edge_data(  # type: ignore[override]  # Has an additional `key` keyword argument
        self, u, v, key: Incomplete | None = None, default: Incomplete | None = None
    ): ...
    def copy(self, as_view: bool = False) -> MultiGraph[_Node]: ...
    def to_directed(self, as_view: bool = False) -> MultiDiGraph[_Node]: ...
    def to_undirected(self, as_view: bool = False) -> MultiGraph[_Node]: ...
    def number_of_edges(self, u: _Node | None = None, v: _Node | None = None) -> int: ...



from typing import Any

from jmespath import parser as parser
from jmespath.visitor import Options as Options

def compile(expression: str) -> parser.ParsedResult: ...
def search(expression: str, data: Any, options: Options | None = None) -> Any: ...



from collections.abc import Iterator, Sequence
from typing import Any, Generic, TypeVar

from wtforms.fields.core import Field, _Widget
from wtforms.form import BaseForm
from wtforms.meta import DefaultMeta, _SupportsGettextAndNgettext

_BoundFormT = TypeVar("_BoundFormT", bound=BaseForm)

class FormField(Field, Generic[_BoundFormT]):
    form_class: type[_BoundFormT]
    form: _BoundFormT
    separator: str
    def __init__(
        self: FormField[_BoundFormT],
        form_class: type[_BoundFormT],
        label: str | None = None,
        validators: None = None,
        separator: str = "-",
        *,
        description: str = "",
        id: str | None = None,
        default: object | None = None,
        widget: _Widget[FormField[_BoundFormT]] | None = None,
        render_kw: dict[str, Any] | None = None,
        name: str | None = None,
        _form: BaseForm | None = None,
        _prefix: str = "",
        _translations: _SupportsGettextAndNgettext | None = None,
        _meta: DefaultMeta | None = None,
    ) -> None: ...
    def __iter__(self) -> Iterator[Field]: ...
    def __getitem__(self, name: str) -> Field: ...
    def __getattr__(self, name: str) -> Field: ...
    @property
    def data(self) -> dict[str, Any]: ...
    @property
    def errors(self) -> dict[str | None, Sequence[str]]: ...  # type: ignore[override]



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def louvain_communities(
    G, weight: str = "weight", resolution: float = 1, threshold: float = 1e-07, seed: Incomplete | None = None
): ...
@_dispatch
def louvain_partitions(
    G, weight: str = "weight", resolution: float = 1, threshold: float = 1e-07, seed: Incomplete | None = None
) -> Generator[Incomplete, None, None]: ...



from _typeshed import Incomplete
from typing import Any

class QueryIterator:
    def __iter__(self): ...
    def has_next(self) -> None: ...
    def has_next_async(self) -> None: ...
    def probably_has_next(self) -> None: ...
    def next(self) -> None: ...
    def cursor_before(self) -> None: ...
    def cursor_after(self) -> None: ...
    def index_list(self) -> None: ...

class Cursor:
    @classmethod
    def from_websafe_string(cls, urlsafe): ...
    cursor: Any
    def __init__(self, cursor: Incomplete | None = ..., urlsafe: Incomplete | None = ...) -> None: ...
    def to_websafe_string(self): ...
    def urlsafe(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __hash__(self) -> int: ...



from _typeshed import Incomplete

class ModeDescriptor:
    mode: Incomplete
    bands: Incomplete
    basemode: Incomplete
    basetype: Incomplete
    def __init__(self, mode, bands, basemode, basetype, typestr) -> None: ...

def getmode(mode): ...



from collections.abc import Sequence
from enum import Enum

from antlr4.atn.ATN import ATN as ATN
from antlr4.atn.ATNConfig import ATNConfig as ATNConfig
from antlr4.atn.ATNConfigSet import ATNConfigSet as ATNConfigSet
from antlr4.atn.ATNState import RuleStopState as RuleStopState
from antlr4.atn.SemanticContext import SemanticContext as SemanticContext

class PredictionMode(Enum):
    SLL: int
    LL: int
    LL_EXACT_AMBIG_DETECTION: int
    @classmethod
    def hasSLLConflictTerminatingPrediction(cls, mode: PredictionMode, configs: ATNConfigSet): ...
    @classmethod
    def hasConfigInRuleStopState(cls, configs: ATNConfigSet): ...
    @classmethod
    def allConfigsInRuleStopStates(cls, configs: ATNConfigSet): ...
    @classmethod
    def resolvesToJustOneViableAlt(cls, altsets: Sequence[set[int]]): ...
    @classmethod
    def allSubsetsConflict(cls, altsets: Sequence[set[int]]): ...
    @classmethod
    def hasNonConflictingAltSet(cls, altsets: Sequence[set[int]]): ...
    @classmethod
    def hasConflictingAltSet(cls, altsets: Sequence[set[int]]): ...
    @classmethod
    def allSubsetsEqual(cls, altsets: Sequence[set[int]]): ...
    @classmethod
    def getUniqueAlt(cls, altsets: Sequence[set[int]]): ...
    @classmethod
    def getAlts(cls, altsets: Sequence[set[int]]): ...
    @classmethod
    def getConflictingAltSubsets(cls, configs: ATNConfigSet): ...
    @classmethod
    def getStateToAltMap(cls, configs: ATNConfigSet): ...
    @classmethod
    def hasStateAssociatedWithOneAlt(cls, configs: ATNConfigSet): ...
    @classmethod
    def getSingleViableAlt(cls, altsets: Sequence[set[int]]): ...



from . import items as items
from .console_menu import ConsoleMenu as ConsoleMenu, Screen as Screen, clear_terminal as clear_terminal
from .menu_formatter import MenuFormatBuilder as MenuFormatBuilder
from .multiselect_menu import MultiSelectMenu as MultiSelectMenu
from .prompt_utils import PromptUtils as PromptUtils
from .selection_menu import SelectionMenu as SelectionMenu



from _typeshed import Incomplete
from typing import Any

log: Any
SERVICE_NAME: str
ORIGIN: str
IMDS_URL: str

def initialize() -> None: ...
def get_token(): ...
def get_metadata(token: Incomplete | None = None): ...
def parse_metadata_json(json_str): ...
def do_request(url, headers: Incomplete | None = None, method: str = "GET"): ...



from _typeshed import Incomplete

class LineProtocolError:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        code: Incomplete | None = None,
        message: Incomplete | None = None,
        op: Incomplete | None = None,
        err: Incomplete | None = None,
        line: Incomplete | None = None,
    ) -> None: ...
    @property
    def code(self): ...
    @code.setter
    def code(self, code) -> None: ...
    @property
    def message(self): ...
    @message.setter
    def message(self, message) -> None: ...
    @property
    def op(self): ...
    @op.setter
    def op(self, op) -> None: ...
    @property
    def err(self): ...
    @err.setter
    def err(self, err) -> None: ...
    @property
    def line(self): ...
    @line.setter
    def line(self, line) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatch

@_dispatch
def dfs_edges(
    G: Graph[_Node], source: _Node | None = None, depth_limit: int | None = None
) -> Generator[tuple[_Node, _Node], None, None]: ...
@_dispatch
def dfs_tree(G, source: Incomplete | None = None, depth_limit: Incomplete | None = None): ...
@_dispatch
def dfs_predecessors(G, source: Incomplete | None = None, depth_limit: Incomplete | None = None): ...
@_dispatch
def dfs_successors(G, source: Incomplete | None = None, depth_limit: Incomplete | None = None): ...
@_dispatch
def dfs_postorder_nodes(G, source: Incomplete | None = None, depth_limit: Incomplete | None = None): ...
@_dispatch
def dfs_preorder_nodes(G, source: Incomplete | None = None, depth_limit: Incomplete | None = None): ...
@_dispatch
def dfs_labeled_edges(G, source: Incomplete | None = None, depth_limit: Incomplete | None = None) -> None: ...



from _typeshed import Incomplete

from .commands import SearchCommands

class Search(SearchCommands):
    class BatchIndexer:
        def __init__(self, client, chunk_size: int = 1000) -> None: ...
        def add_document(
            self,
            doc_id,
            nosave: bool = False,
            score: float = 1.0,
            payload: Incomplete | None = None,
            replace: bool = False,
            partial: bool = False,
            no_create: bool = False,
            **fields,
        ): ...
        def add_document_hash(self, doc_id, score: float = 1.0, replace: bool = False): ...
        def commit(self): ...

    def __init__(self, client, index_name: str = "idx") -> None: ...



from _typeshed import Incomplete

NUL: int
ENQ: int
BEL: int
BS: int
HT: int
LF: int
VT: int
FF: int
CR: int
SO: int
SI: int
XON: int
XOFF: int
CAN: int
SUB: int
ESC: int
DEL: int
SPACE: str
PY3: Incomplete
unicode = str

def constrain(n, min, max): ...

class screen:
    rows: Incomplete
    cols: Incomplete
    encoding: Incomplete
    encoding_errors: Incomplete
    decoder: Incomplete
    cur_r: int
    cur_c: int
    cur_saved_r: int
    cur_saved_c: int
    scroll_row_start: int
    scroll_row_end: Incomplete
    w: Incomplete
    def __init__(self, r: int = 24, c: int = 80, encoding: str = "latin-1", encoding_errors: str = "replace") -> None: ...
    def dump(self): ...
    def pretty(self): ...
    def fill(self, ch=" ") -> None: ...
    def fill_region(self, rs, cs, re, ce, ch=" ") -> None: ...
    def cr(self) -> None: ...
    def lf(self) -> None: ...
    def crlf(self) -> None: ...
    def newline(self) -> None: ...
    def put_abs(self, r, c, ch) -> None: ...
    def put(self, ch) -> None: ...
    def insert_abs(self, r, c, ch) -> None: ...
    def insert(self, ch) -> None: ...
    def get_abs(self, r, c): ...
    def get(self) -> None: ...
    def get_region(self, rs, cs, re, ce): ...
    def cursor_constrain(self) -> None: ...
    def cursor_home(self, r: int = 1, c: int = 1) -> None: ...
    def cursor_back(self, count: int = 1) -> None: ...
    def cursor_down(self, count: int = 1) -> None: ...
    def cursor_forward(self, count: int = 1) -> None: ...
    def cursor_up(self, count: int = 1) -> None: ...
    def cursor_up_reverse(self) -> None: ...
    def cursor_force_position(self, r, c) -> None: ...
    def cursor_save(self) -> None: ...
    def cursor_unsave(self) -> None: ...
    def cursor_save_attrs(self) -> None: ...
    def cursor_restore_attrs(self) -> None: ...
    def scroll_constrain(self) -> None: ...
    def scroll_screen(self) -> None: ...
    def scroll_screen_rows(self, rs, re) -> None: ...
    def scroll_down(self) -> None: ...
    def scroll_up(self) -> None: ...
    def erase_end_of_line(self) -> None: ...
    def erase_start_of_line(self) -> None: ...
    def erase_line(self) -> None: ...
    def erase_down(self) -> None: ...
    def erase_up(self) -> None: ...
    def erase_screen(self) -> None: ...
    def set_tab(self) -> None: ...
    def clear_tab(self) -> None: ...
    def clear_all_tabs(self) -> None: ...



from consolemenu.format.menu_borders import MenuBorderStyle as MenuBorderStyle, MenuBorderStyleFactory as MenuBorderStyleFactory
from consolemenu.format.menu_margins import MenuMargins as MenuMargins
from consolemenu.format.menu_padding import MenuPadding as MenuPadding

class MenuStyle:
    def __init__(
        self,
        margins: MenuMargins | None = None,
        padding: MenuPadding | None = None,
        border_style: MenuBorderStyle | None = None,
        border_style_type: int | None = None,
        border_style_factory: MenuBorderStyleFactory | None = None,
    ) -> None: ...
    @property
    def margins(self) -> MenuMargins: ...
    @margins.setter
    def margins(self, margins: MenuMargins) -> None: ...
    @property
    def padding(self) -> MenuPadding: ...
    @padding.setter
    def padding(self, padding: MenuPadding) -> None: ...
    @property
    def border_style(self) -> MenuBorderStyle: ...
    @border_style.setter
    def border_style(self, border_style: MenuBorderStyle) -> None: ...
    @property
    def border_style_factory(self) -> MenuBorderStyleFactory: ...
    @border_style_factory.setter
    def border_style_factory(self, border_style_factory: MenuBorderStyleFactory) -> None: ...



from networkx.utils.backends import _dispatch

@_dispatch
def union_all(graphs, rename=()): ...
@_dispatch
def disjoint_union_all(graphs): ...
@_dispatch
def compose_all(graphs): ...
@_dispatch
def intersection_all(graphs): ...



from typing import Final

SUN_JKS_ALGO_ID: Final[tuple[int, ...]]
SUN_JCE_ALGO_ID: Final[tuple[int, ...]]

def jks_pkey_encrypt(key: bytes | bytearray, password_str: str) -> bytes: ...
def jks_pkey_decrypt(data: bytes | bytearray, password_str: str) -> bytes: ...
def jce_pbe_decrypt(data: bytes | bytearray, password: str, salt: bytes, iteration_count: int) -> bytes: ...



import socket
from _typeshed import Incomplete

PROXY_TYPE_SOCKS4: int
PROXY_TYPE_SOCKS5: int
PROXY_TYPE_HTTP: int
PROXY_TYPE_HTTP_NO_TUNNEL: int

class ProxyError(Exception): ...
class GeneralProxyError(ProxyError): ...
class Socks5AuthError(ProxyError): ...
class Socks5Error(ProxyError): ...
class Socks4Error(ProxyError): ...
class HTTPError(ProxyError): ...

def setdefaultproxy(
    proxytype: Incomplete | None = None,
    addr: Incomplete | None = None,
    port: Incomplete | None = None,
    rdns: bool = True,
    username: Incomplete | None = None,
    password: Incomplete | None = None,
) -> None: ...
def wrapmodule(module) -> None: ...

class socksocket(socket.socket):
    def __init__(self, family=..., type=..., proto: int = 0, _sock: Incomplete | None = None) -> None: ...
    def sendall(self, content, *args): ...
    def setproxy(
        self,
        proxytype: Incomplete | None = None,
        addr: Incomplete | None = None,
        port: Incomplete | None = None,
        rdns: bool = True,
        username: Incomplete | None = None,
        password: Incomplete | None = None,
        headers: Incomplete | None = None,
    ) -> None: ...
    def getproxysockname(self): ...
    def getproxypeername(self): ...
    def getpeername(self): ...
    def connect(self, destpair) -> None: ...



from _typeshed import StrOrBytesPath
from collections.abc import Sequence
from types import CodeType
from typing import Any, final

def expr(source: str) -> STType: ...
def suite(source: str) -> STType: ...
def sequence2st(sequence: Sequence[Any]) -> STType: ...
def tuple2st(sequence: Sequence[Any]) -> STType: ...
def st2list(st: STType, line_info: bool = ..., col_info: bool = ...) -> list[Any]: ...
def st2tuple(st: STType, line_info: bool = ..., col_info: bool = ...) -> tuple[Any, ...]: ...
def compilest(st: STType, filename: StrOrBytesPath = ...) -> CodeType: ...
def isexpr(st: STType) -> bool: ...
def issuite(st: STType) -> bool: ...

class ParserError(Exception): ...

@final
class STType:
    def compile(self, filename: StrOrBytesPath = ...) -> CodeType: ...
    def isexpr(self) -> bool: ...
    def issuite(self) -> bool: ...
    def tolist(self, line_info: bool = ..., col_info: bool = ...) -> list[Any]: ...
    def totuple(self, line_info: bool = ..., col_info: bool = ...) -> tuple[Any, ...]: ...



from _typeshed import Incomplete

class Stat:
    h: Incomplete
    bands: Incomplete
    count: list[int]
    mean: list[float]
    rms: list[float]
    stddev: list[float]
    var: list[float]
    def __init__(self, image_or_list, mask: Incomplete | None = None) -> None: ...
    def __getattr__(self, id: str): ...

Global = Stat



from _typeshed import Incomplete

from influxdb_client.domain.view_properties import ViewProperties

class TableViewProperties(ViewProperties):
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        type: Incomplete | None = None,
        queries: Incomplete | None = None,
        colors: Incomplete | None = None,
        shape: Incomplete | None = None,
        note: Incomplete | None = None,
        show_note_when_empty: Incomplete | None = None,
        table_options: Incomplete | None = None,
        field_options: Incomplete | None = None,
        time_format: Incomplete | None = None,
        decimal_places: Incomplete | None = None,
    ) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def queries(self): ...
    @queries.setter
    def queries(self, queries) -> None: ...
    @property
    def colors(self): ...
    @colors.setter
    def colors(self, colors) -> None: ...
    @property
    def shape(self): ...
    @shape.setter
    def shape(self, shape) -> None: ...
    @property
    def note(self): ...
    @note.setter
    def note(self, note) -> None: ...
    @property
    def show_note_when_empty(self): ...
    @show_note_when_empty.setter
    def show_note_when_empty(self, show_note_when_empty) -> None: ...
    @property
    def table_options(self): ...
    @table_options.setter
    def table_options(self, table_options) -> None: ...
    @property
    def field_options(self): ...
    @field_options.setter
    def field_options(self, field_options) -> None: ...
    @property
    def time_format(self): ...
    @time_format.setter
    def time_format(self, time_format) -> None: ...
    @property
    def decimal_places(self): ...
    @decimal_places.setter
    def decimal_places(self, decimal_places) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from collections.abc import Awaitable, Callable, Mapping
from types import TracebackType
from typing import Any, Generic
from typing_extensions import Self

from redis.asyncio.client import ResponseCallbackT
from redis.asyncio.connection import BaseParser, Connection, Encoder
from redis.asyncio.parser import CommandsParser
from redis.client import AbstractRedis
from redis.cluster import AbstractRedisCluster, LoadBalancer

# TODO: add  AsyncRedisClusterCommands stubs
# from redis.commands import AsyncRedisClusterCommands
from redis.commands.core import _StrType
from redis.credentials import CredentialProvider
from redis.retry import Retry
from redis.typing import AnyKeyT, EncodableT, KeyT

# It uses `DefaultParser` in real life, but it is a dynamic base class.
class ClusterParser(BaseParser): ...

class RedisCluster(AbstractRedis, AbstractRedisCluster, Generic[_StrType]):  # TODO: AsyncRedisClusterCommands
    retry: Retry | None
    connection_kwargs: dict[str, Any]
    nodes_manager: NodesManager
    encoder: Encoder
    read_from_replicas: bool
    reinitialize_steps: int
    cluster_error_retry_attempts: int
    reinitialize_counter: int
    commands_parser: CommandsParser
    node_flags: set[str]
    command_flags: dict[str, str]
    response_callbacks: Incomplete
    result_callbacks: dict[str, Callable[[Incomplete, Incomplete], Incomplete]]
    def __init__(
        self,
        host: str | None = None,
        port: str | int = 6379,
        # Cluster related kwargs
        startup_nodes: list[ClusterNode] | None = None,
        require_full_coverage: bool = True,
        read_from_replicas: bool = False,
        reinitialize_steps: int = 5,
        cluster_error_retry_attempts: int = 3,
        connection_error_retry_attempts: int = 3,
        max_connections: int = 2147483648,
        # Client related kwargs
        db: str | int = 0,
        path: str | None = None,
        credential_provider: CredentialProvider | None = None,
        username: str | None = None,
        password: str | None = None,
        client_name: str | None = None,
        # Encoding related kwargs
        encoding: str = "utf-8",
        encoding_errors: str = "strict",
        decode_responses: bool = False,
        # Connection related kwargs
        health_check_interval: float = 0,
        socket_connect_timeout: float | None = None,
        socket_keepalive: bool = False,
        socket_keepalive_options: Mapping[int, int | bytes] | None = None,
        socket_timeout: float | None = None,
        retry: Retry | None = None,
        retry_on_error: list[Exception] | None = None,
        # SSL related kwargs
        ssl: bool = False,
        ssl_ca_certs: str | None = None,
        ssl_ca_data: str | None = None,
        ssl_cert_reqs: str = "required",
        ssl_certfile: str | None = None,
        ssl_check_hostname: bool = False,
        ssl_keyfile: str | None = None,
        address_remap: Callable[[str, int], tuple[str, int]] | None = None,
    ) -> None: ...
    async def initialize(self) -> Self: ...
    async def close(self) -> None: ...
    async def __aenter__(self) -> Self: ...
    async def __aexit__(
        self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None
    ) -> None: ...
    def __await__(self) -> Awaitable[Self]: ...
    def __del__(self) -> None: ...
    async def on_connect(self, connection: Connection) -> None: ...
    def get_nodes(self) -> list[ClusterNode]: ...
    def get_primaries(self) -> list[ClusterNode]: ...
    def get_replicas(self) -> list[ClusterNode]: ...
    def get_random_node(self) -> ClusterNode: ...
    def get_default_node(self) -> ClusterNode: ...
    def set_default_node(self, node: ClusterNode) -> None: ...
    def get_node(self, host: str | None = None, port: int | None = None, node_name: str | None = None) -> ClusterNode | None: ...
    def get_node_from_key(self, key: str, replica: bool = False) -> ClusterNode | None: ...
    def keyslot(self, key: EncodableT) -> int: ...
    def get_encoder(self) -> Encoder: ...
    def get_connection_kwargs(self) -> dict[str, Any | None]: ...
    def set_response_callback(self, command: str, callback: ResponseCallbackT) -> None: ...
    async def execute_command(self, *args: EncodableT, **kwargs: Any) -> Any: ...
    def pipeline(self, transaction: Any | None = None, shard_hint: Any | None = None) -> ClusterPipeline[_StrType]: ...
    @classmethod
    def from_url(cls, url: str, **kwargs) -> Self: ...

class ClusterNode:
    host: str
    port: str | int
    name: str
    server_type: str | None
    max_connections: int
    connection_class: type[Connection]
    connection_kwargs: dict[str, Any]
    response_callbacks: dict[Incomplete, Incomplete]
    def __init__(
        self,
        host: str,
        port: str | int,
        server_type: str | None = None,
        *,
        max_connections: int = 2147483648,
        connection_class: type[Connection] = ...,
        **connection_kwargs: Any,
    ) -> None: ...
    def __eq__(self, obj: object) -> bool: ...
    def __del__(self) -> None: ...
    async def disconnect(self) -> None: ...
    def acquire_connection(self) -> Connection: ...
    async def parse_response(self, connection: Connection, command: str, **kwargs: Any) -> Any: ...
    async def execute_command(self, *args: Any, **kwargs: Any) -> Any: ...
    async def execute_pipeline(self, commands: list[PipelineCommand]) -> bool: ...

class NodesManager:
    startup_nodes: dict[str, ClusterNode]
    require_full_coverage: bool
    connection_kwargs: dict[str, Any]
    default_node: ClusterNode | None
    nodes_cache: dict[str, ClusterNode]
    slots_cache: dict[int, list[ClusterNode]]
    read_load_balancer: LoadBalancer
    address_remap: Callable[[str, int], tuple[str, int]] | None
    def __init__(
        self,
        startup_nodes: list[ClusterNode],
        require_full_coverage: bool,
        connection_kwargs: dict[str, Any],
        address_remap: Callable[[str, int], tuple[str, int]] | None = None,
    ) -> None: ...
    def get_node(self, host: str | None = None, port: int | None = None, node_name: str | None = None) -> ClusterNode | None: ...
    def set_nodes(self, old: dict[str, ClusterNode], new: dict[str, ClusterNode], remove_old: bool = False) -> None: ...
    def get_node_from_slot(self, slot: int, read_from_replicas: bool = False) -> ClusterNode: ...
    def get_nodes_by_server_type(self, server_type: str) -> list[ClusterNode]: ...
    async def initialize(self) -> None: ...
    async def close(self, attr: str = "nodes_cache") -> None: ...
    def remap_host_port(self, host: str, port: int) -> tuple[str, int]: ...

class ClusterPipeline(AbstractRedis, AbstractRedisCluster, Generic[_StrType]):  # TODO: AsyncRedisClusterCommands
    def __init__(self, client: RedisCluster[_StrType]) -> None: ...
    async def initialize(self) -> Self: ...
    async def __aenter__(self) -> Self: ...
    async def __aexit__(
        self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None
    ) -> None: ...
    def __await__(self) -> Awaitable[Self]: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None
    ) -> None: ...
    def __bool__(self) -> bool: ...
    def __len__(self) -> int: ...
    def execute_command(self, *args: KeyT | EncodableT, **kwargs: Any) -> Self: ...
    async def execute(self, raise_on_error: bool = True, allow_redirections: bool = True) -> list[Any]: ...
    def mset_nonatomic(self, mapping: Mapping[AnyKeyT, EncodableT]) -> Self: ...

class PipelineCommand:
    args: Any
    kwargs: Any
    position: int
    result: Exception | None | Any
    def __init__(self, position: int, *args: Any, **kwargs: Any) -> None: ...



from .austria import Austria as Austria
from .belarus import Belarus as Belarus
from .belgium import Belgium as Belgium
from .bulgaria import Bulgaria as Bulgaria
from .cayman_islands import CaymanIslands as CaymanIslands
from .croatia import Croatia as Croatia
from .cyprus import Cyprus as Cyprus
from .czech_republic import CzechRepublic as CzechRepublic
from .denmark import Denmark as Denmark
from .estonia import Estonia as Estonia
from .european_central_bank import EuropeanCentralBank as EuropeanCentralBank
from .finland import Finland as Finland
from .france import France as France, FranceAlsaceMoselle as FranceAlsaceMoselle
from .georgia import Georgia as Georgia
from .germany import (
    BadenWurttemberg as BadenWurttemberg,
    Bavaria as Bavaria,
    Berlin as Berlin,
    Brandenburg as Brandenburg,
    Bremen as Bremen,
    Germany as Germany,
    Hamburg as Hamburg,
    Hesse as Hesse,
    LowerSaxony as LowerSaxony,
    MecklenburgVorpommern as MecklenburgVorpommern,
    NorthRhineWestphalia as NorthRhineWestphalia,
    RhinelandPalatinate as RhinelandPalatinate,
    Saarland as Saarland,
    Saxony as Saxony,
    SaxonyAnhalt as SaxonyAnhalt,
    SchleswigHolstein as SchleswigHolstein,
    Thuringia as Thuringia,
)
from .greece import Greece as Greece
from .guernsey import Guernsey as Guernsey
from .hungary import Hungary as Hungary
from .iceland import Iceland as Iceland
from .ireland import Ireland as Ireland
from .italy import Italy as Italy
from .latvia import Latvia as Latvia
from .lithuania import Lithuania as Lithuania
from .luxembourg import Luxembourg as Luxembourg
from .malta import Malta as Malta
from .monaco import Monaco as Monaco
from .netherlands import Netherlands as Netherlands, NetherlandsWithSchoolHolidays as NetherlandsWithSchoolHolidays
from .norway import Norway as Norway
from .poland import Poland as Poland
from .portugal import Portugal as Portugal
from .romania import Romania as Romania
from .russia import Russia as Russia
from .scotland import (
    Aberdeen as Aberdeen,
    Angus as Angus,
    Arbroath as Arbroath,
    Ayr as Ayr,
    CarnoustieMonifieth as CarnoustieMonifieth,
    Clydebank as Clydebank,
    DumfriesGalloway as DumfriesGalloway,
    Dundee as Dundee,
    EastDunbartonshire as EastDunbartonshire,
    Edinburgh as Edinburgh,
    Elgin as Elgin,
    Falkirk as Falkirk,
    Fife as Fife,
    Galashiels as Galashiels,
    Glasgow as Glasgow,
    Hawick as Hawick,
    Inverclyde as Inverclyde,
    Inverness as Inverness,
    Kilmarnock as Kilmarnock,
    Lanark as Lanark,
    Linlithgow as Linlithgow,
    Lochaber as Lochaber,
    NorthLanarkshire as NorthLanarkshire,
    Paisley as Paisley,
    Perth as Perth,
    Scotland as Scotland,
    ScottishBorders as ScottishBorders,
    SouthLanarkshire as SouthLanarkshire,
    Stirling as Stirling,
    WestDunbartonshire as WestDunbartonshire,
)
from .serbia import Serbia as Serbia
from .slovakia import Slovakia as Slovakia
from .slovenia import Slovenia as Slovenia
from .spain import (
    Andalusia as Andalusia,
    Aragon as Aragon,
    Asturias as Asturias,
    BalearicIslands as BalearicIslands,
    BasqueCountry as BasqueCountry,
    CanaryIslands as CanaryIslands,
    Cantabria as Cantabria,
    CastileAndLeon as CastileAndLeon,
    CastillaLaMancha as CastillaLaMancha,
    Catalonia as Catalonia,
    CommunityofMadrid as CommunityofMadrid,
    Extremadura as Extremadura,
    Galicia as Galicia,
    LaRioja as LaRioja,
    Murcia as Murcia,
    Navarre as Navarre,
    Spain as Spain,
    ValencianCommunity as ValencianCommunity,
)
from .sweden import Sweden as Sweden
from .switzerland import (
    Aargau as Aargau,
    AppenzellAusserrhoden as AppenzellAusserrhoden,
    AppenzellInnerrhoden as AppenzellInnerrhoden,
    BaselLandschaft as BaselLandschaft,
    BaselStadt as BaselStadt,
    Bern as Bern,
    Fribourg as Fribourg,
    Geneva as Geneva,
    Glarus as Glarus,
    Graubunden as Graubunden,
    Jura as Jura,
    Luzern as Luzern,
    Neuchatel as Neuchatel,
    Nidwalden as Nidwalden,
    Obwalden as Obwalden,
    Schaffhausen as Schaffhausen,
    Schwyz as Schwyz,
    Solothurn as Solothurn,
    StGallen as StGallen,
    Switzerland as Switzerland,
    Thurgau as Thurgau,
    Ticino as Ticino,
    Uri as Uri,
    Valais as Valais,
    Vaud as Vaud,
    Zug as Zug,
    Zurich as Zurich,
)
from .turkey import Turkey as Turkey
from .ukraine import Ukraine as Ukraine
from .united_kingdom import UnitedKingdom as UnitedKingdom, UnitedKingdomNorthernIreland as UnitedKingdomNorthernIreland



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def bfs_edges(
    G, source, reverse: bool = False, depth_limit: Incomplete | None = None, sort_neighbors: Incomplete | None = None
) -> Generator[Incomplete, Incomplete, None]: ...
@_dispatch
def bfs_tree(
    G, source, reverse: bool = False, depth_limit: Incomplete | None = None, sort_neighbors: Incomplete | None = None
): ...
@_dispatch
def bfs_predecessors(
    G, source, depth_limit: Incomplete | None = None, sort_neighbors: Incomplete | None = None
) -> Generator[Incomplete, None, None]: ...
@_dispatch
def bfs_successors(
    G, source, depth_limit: Incomplete | None = None, sort_neighbors: Incomplete | None = None
) -> Generator[Incomplete, None, None]: ...
@_dispatch
def bfs_layers(G, sources) -> Generator[Incomplete, None, None]: ...
@_dispatch
def descendants_at_distance(G, source, distance): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def approximate_current_flow_betweenness_centrality(
    G,
    normalized: bool = True,
    weight: Incomplete | None = None,
    dtype=...,
    solver: str = "full",
    epsilon: float = 0.5,
    kmax: int = 10000,
    seed: Incomplete | None = None,
): ...
@_dispatch
def current_flow_betweenness_centrality(
    G, normalized: bool = True, weight: Incomplete | None = None, dtype=..., solver: str = "full"
): ...
@_dispatch
def edge_current_flow_betweenness_centrality(
    G, normalized: bool = True, weight: Incomplete | None = None, dtype=..., solver: str = "full"
): ...



from _typeshed import ConvertibleToInt, Incomplete, Unused
from typing import ClassVar, Literal
from typing_extensions import TypeAlias
from zipfile import ZipFile

from openpyxl.descriptors.base import Bool, Integer, NoneSet, String, Typed, _ConvertibleToBool
from openpyxl.descriptors.nested import NestedText
from openpyxl.descriptors.serialisable import Serialisable
from openpyxl.packaging.relationship import Relationship
from openpyxl.xml.functions import Element

_ExternalCellType: TypeAlias = Literal["b", "d", "n", "e", "s", "str", "inlineStr"]

class ExternalCell(Serialisable):
    r: String[Literal[False]]
    t: NoneSet[_ExternalCellType]
    vm: Integer[Literal[True]]
    v: NestedText[str, Literal[True]]
    def __init__(
        self, r: str, t: _ExternalCellType | Literal["none"] | None = None, vm: ConvertibleToInt | None = None, v: object = None
    ) -> None: ...

class ExternalRow(Serialisable):
    r: Integer[Literal[False]]
    cell: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, r: ConvertibleToInt, cell: Incomplete | None = None) -> None: ...

class ExternalSheetData(Serialisable):
    sheetId: Integer[Literal[False]]
    refreshError: Bool[Literal[True]]
    row: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, sheetId: ConvertibleToInt, refreshError: _ConvertibleToBool | None = None, row=()) -> None: ...

class ExternalSheetDataSet(Serialisable):
    sheetData: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, sheetData: Incomplete | None = None) -> None: ...

class ExternalSheetNames(Serialisable):
    sheetName: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, sheetName=()) -> None: ...

class ExternalDefinedName(Serialisable):
    tagname: ClassVar[str]
    name: String[Literal[False]]
    refersTo: String[Literal[True]]
    sheetId: Integer[Literal[True]]
    def __init__(self, name: str, refersTo: str | None = None, sheetId: ConvertibleToInt | None = None) -> None: ...

class ExternalBook(Serialisable):
    tagname: ClassVar[str]
    sheetNames: Typed[ExternalSheetNames, Literal[True]]
    definedNames: Incomplete
    sheetDataSet: Typed[ExternalSheetDataSet, Literal[True]]
    id: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self,
        sheetNames: ExternalSheetNames | None = None,
        definedNames=(),
        sheetDataSet: ExternalSheetDataSet | None = None,
        id: Incomplete | None = None,
    ) -> None: ...

class ExternalLink(Serialisable):
    tagname: ClassVar[str]
    mime_type: str
    externalBook: Typed[ExternalBook, Literal[True]]
    file_link: Typed[Relationship, Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(
        self, externalBook: ExternalBook | None = None, ddeLink: Unused = None, oleLink: Unused = None, extLst: Unused = None
    ) -> None: ...
    def to_tree(self) -> Element: ...  # type: ignore[override]
    @property
    def path(self) -> str: ...

def read_external_link(archive: ZipFile, book_path: str) -> ExternalLink: ...



import weakref
from collections.abc import Callable, Iterable, Sequence
from types import FrameType, TracebackType
from typing import Any, ClassVar, Generic, TypeVar, overload
from typing_extensions import ParamSpec, Self

import greenlet
from gevent._types import _Loop
from gevent._util import readproperty

_T = TypeVar("_T")
_G = TypeVar("_G", bound=greenlet.greenlet)
_P = ParamSpec("_P")

class Greenlet(greenlet.greenlet, Generic[_P, _T]):
    # we can't use _P.args/_P.kwargs here because pyright will complain
    # mypy doesn't seem to mind though
    args: tuple[Any, ...]
    kwargs: dict[str, Any]
    value: _T | None
    @overload
    def __init__(self: Greenlet[_P, _T], run: Callable[_P, _T], *args: _P.args, **kwargs: _P.kwargs) -> None: ...
    @overload
    def __init__(self: Greenlet[[], None]) -> None: ...
    @readproperty
    def name(self) -> str: ...
    @property
    def minimal_ident(self) -> int: ...
    @property
    def loop(self) -> _Loop: ...
    @property
    def dead(self) -> bool: ...
    @property
    def started(self) -> bool: ...
    @property
    def exception(self) -> BaseException | None: ...
    @property
    def exc_info(self) -> tuple[type[BaseException], BaseException, TracebackType | None] | None: ...
    @staticmethod
    def add_spawn_callback(callback: Callable[[Greenlet[..., Any]], object]) -> None: ...
    @staticmethod
    def remove_spawn_callback(callback: Callable[[Greenlet[..., Any]], object]) -> None: ...
    def get(self, block: bool = True, timeout: float | None = None) -> _T: ...
    def has_links(self) -> bool: ...
    def join(self, timeout: float | None = None) -> None: ...
    def kill(
        self, exception: type[BaseException] | BaseException = ..., block: bool = True, timeout: float | None = None
    ) -> None: ...
    def link(self, callback: Callable[[Self], object]) -> None: ...
    def link_exception(self, callback: Callable[[Self], object]) -> None: ...
    def link_value(self, callback: Callable[[Self], object]) -> None: ...
    def rawlink(self, callback: Callable[[Self], object]) -> None: ...
    def unlink(self, callback: Callable[[Self], Any]) -> None: ...
    def unlink_all(self) -> None: ...
    def ready(self) -> bool: ...
    def run(self) -> Any: ...
    @overload
    @classmethod
    def spawn(cls, run: Callable[_P, _T], /, *args: _P.args, **kwargs: _P.kwargs) -> Self: ...
    @overload
    @classmethod
    def spawn(cls) -> Greenlet[[], None]: ...
    @overload
    @classmethod
    def spawn_later(cls, seconds: float, run: Callable[_P, _T], *args: _P.args, **kwargs: _P.kwargs) -> Self: ...
    @overload
    @classmethod
    def spawn_later(cls, seconds: float) -> Greenlet[[], None]: ...
    def start(self) -> None: ...
    def start_later(self, seconds: float) -> None: ...
    def successful(self) -> bool: ...
    def __bool__(self) -> bool: ...
    def __enter__(self) -> Self: ...
    def __exit__(self, t: type[BaseException] | None, v: BaseException | None, tb: TracebackType | None) -> None: ...

    # since these are for instrumentation which is disabled by default, we could
    # consider just not annotating them...
    spawning_stack_limit: ClassVar[int]
    spawn_tree_locals: dict[str, Any] | None
    spawning_greenlet: weakref.ref[greenlet.greenlet] | None
    # not quite accurate, since it may be an internal dummy type instead
    # but since it has all the same fields as FrameType we shouldn't care
    spawning_stack: FrameType | None

def joinall(
    greenlets: Sequence[_G], timeout: float | None = None, raise_error: bool = False, count: int | None = None
) -> list[_G]: ...
def killall(
    greenlets: Iterable[greenlet.greenlet],
    exception: type[BaseException] | BaseException = ...,
    block: bool = True,
    timeout: float | None = None,
) -> None: ...



from _typeshed import Incomplete, Unused
from typing import NoReturn
from typing_extensions import Self

from ._imaging import _PixelAccessor
from .Image import Image

MAXBLOCK: int
SAFEBLOCK: Incomplete
LOAD_TRUNCATED_IMAGES: bool
ERRORS: Incomplete

def raise_oserror(error) -> NoReturn: ...

class ImageFile(Image):
    custom_mimetype: Incomplete
    tile: list[Incomplete] | None
    readonly: int
    decoderconfig: Incomplete
    decodermaxblock: Incomplete
    fp: Incomplete
    filename: Incomplete
    def __init__(self, fp: Incomplete | None = None, filename: Incomplete | None = None) -> None: ...
    def get_format_mimetype(self): ...
    def verify(self) -> None: ...
    map: Incomplete
    im: Incomplete
    def load(self) -> _PixelAccessor: ...
    def load_prepare(self) -> None: ...
    def load_end(self) -> None: ...

class StubImageFile(ImageFile):
    def load(self) -> _PixelAccessor: ...

class Parser:
    incremental: Incomplete | None
    image: Incomplete | None
    data: Incomplete | None
    decoder: Incomplete | None
    offset: int
    finished: bool
    def reset(self) -> None: ...
    decode: Incomplete
    def feed(self, data) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(self, *args: Unused) -> None: ...
    def close(self) -> Image: ...

class PyCodecState:
    xsize: int
    ysize: int
    xoff: int
    yoff: int
    def extents(self) -> tuple[int, int, int, int]: ...

class PyCodec:
    im: Incomplete
    state: Incomplete
    fd: Incomplete
    mode: Incomplete
    def __init__(self, mode, *args) -> None: ...
    args: Incomplete
    def init(self, args) -> None: ...
    def cleanup(self) -> None: ...
    def setfd(self, fd) -> None: ...
    def setimage(self, im, extents: Incomplete | None = None) -> None: ...

class PyDecoder:
    im: Incomplete
    state: Incomplete
    fd: Incomplete
    mode: Incomplete
    def __init__(self, mode, *args) -> None: ...
    args: Incomplete
    def init(self, args) -> None: ...
    @property
    def pulls_fd(self): ...
    def decode(self, buffer) -> tuple[int, int]: ...
    def cleanup(self) -> None: ...
    def setfd(self, fd) -> None: ...
    def setimage(self, im, extents: Incomplete | None = None) -> None: ...
    def set_as_raw(self, data, rawmode: Incomplete | None = None) -> None: ...

class PyEncoder(PyCodec):
    @property
    def pushes_fd(self): ...
    def encode(self, bufsize) -> None: ...
    def encode_to_pyfd(self): ...
    def encode_to_file(self, fh, bufsize): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def caveman_graph(l, k): ...
@_dispatch
def connected_caveman_graph(l, k): ...
@_dispatch
def relaxed_caveman_graph(l, k, p, seed: Incomplete | None = None): ...
@_dispatch
def random_partition_graph(sizes, p_in, p_out, seed: Incomplete | None = None, directed: bool = False): ...
@_dispatch
def planted_partition_graph(l, k, p_in, p_out, seed: Incomplete | None = None, directed: bool = False): ...
@_dispatch
def gaussian_random_partition_graph(n, s, v, p_in, p_out, directed: bool = False, seed: Incomplete | None = None): ...
@_dispatch
def ring_of_cliques(num_cliques, clique_size): ...
@_dispatch
def windmill_graph(n, k): ...
@_dispatch
def stochastic_block_model(
    sizes,
    p,
    nodelist: Incomplete | None = None,
    seed: Incomplete | None = None,
    directed: bool = False,
    selfloops: bool = False,
    sparse: bool = True,
): ...
@_dispatch
def LFR_benchmark_graph(
    n,
    tau1,
    tau2,
    mu,
    average_degree: Incomplete | None = None,
    min_degree: Incomplete | None = None,
    max_degree: Incomplete | None = None,
    min_community: Incomplete | None = None,
    max_community: Incomplete | None = None,
    tol: float = 1e-07,
    max_iters: int = 500,
    seed: Incomplete | None = None,
): ...



from _cffi_backend import _CDataBase

class Refspec:
    def __init__(self, owner: _CDataBase, ptr: _CDataBase) -> None: ...
    @property
    def src(self) -> str: ...
    @property
    def dst(self) -> str: ...
    @property
    def force(self) -> bool: ...
    @property
    def string(self) -> str: ...
    @property
    def direction(self) -> int: ...
    def src_matches(self, ref: str) -> bool: ...
    def dst_matches(self, ref: str) -> bool: ...
    def transform(self, ref: str) -> str: ...
    def rtransform(self, ref: str) -> str: ...



from collections.abc import Iterator
from datetime import datetime

from influxdb_client import LabelResponse, LogEvent, Run, TaskCreateRequest, TaskUpdateRequest
from influxdb_client.domain.task import Task

class TasksApi:
    def __init__(self, influxdb_client) -> None: ...
    def find_task_by_id(self, task_id) -> Task: ...
    def find_tasks(
        self, *, name: str = ..., after: str = ..., user: str = ..., org: str = ..., org_id: str = ..., limit: int = ..., **kwargs
    ) -> list[Task]: ...
    def find_tasks_iter(
        self, *, name: str = ..., after: str = ..., user: str = ..., org: str = ..., org_id: str = ..., limit: int = ..., **kwargs
    ) -> Iterator[Task]: ...
    def create_task(self, task: Task | None = None, task_create_request: TaskCreateRequest | None = None) -> Task: ...
    def create_task_every(self, name, flux, every, organization) -> Task: ...
    def create_task_cron(self, name: str, flux: str, cron: str, org_id: str) -> Task: ...
    def delete_task(self, task_id: str): ...
    def update_task(self, task: Task) -> Task: ...
    def update_task_request(self, task_id, task_update_request: TaskUpdateRequest) -> Task: ...
    def clone_task(self, task: Task) -> Task: ...
    def get_labels(self, task_id): ...
    def add_label(self, label_id: str, task_id: str) -> LabelResponse: ...
    def delete_label(self, label_id: str, task_id: str): ...
    def get_members(self, task_id: str): ...
    def add_member(self, member_id, task_id): ...
    def delete_member(self, member_id, task_id): ...
    def get_owners(self, task_id): ...
    def add_owner(self, owner_id, task_id): ...
    def delete_owner(self, owner_id, task_id): ...
    def get_runs(self, task_id, **kwargs) -> list[Run]: ...
    def get_run(self, task_id: str, run_id: str) -> Run: ...
    def get_run_logs(self, task_id: str, run_id: str) -> list[LogEvent]: ...
    def run_manually(self, task_id: str, scheduled_for: datetime | None = None): ...
    def retry_run(self, task_id: str, run_id: str): ...
    def cancel_run(self, task_id: str, run_id: str): ...
    def get_logs(self, task_id: str) -> list[LogEvent]: ...
    def find_tasks_by_user(self, task_user_id): ...



from typing import Any

oem_encoding: Any
NTLM_SIGNATURE: bytes
NTLM_MESSAGE_TYPE_NTLM_NEGOTIATE: int
NTLM_MESSAGE_TYPE_NTLM_CHALLENGE: int
NTLM_MESSAGE_TYPE_NTLM_AUTHENTICATE: int
FLAG_NEGOTIATE_56: int
FLAG_NEGOTIATE_KEY_EXCH: int
FLAG_NEGOTIATE_128: int
FLAG_NEGOTIATE_VERSION: int
FLAG_NEGOTIATE_TARGET_INFO: int
FLAG_REQUEST_NOT_NT_SESSION_KEY: int
FLAG_NEGOTIATE_IDENTIFY: int
FLAG_NEGOTIATE_EXTENDED_SESSIONSECURITY: int
FLAG_TARGET_TYPE_SERVER: int
FLAG_TARGET_TYPE_DOMAIN: int
FLAG_NEGOTIATE_ALWAYS_SIGN: int
FLAG_NEGOTIATE_OEM_WORKSTATION_SUPPLIED: int
FLAG_NEGOTIATE_OEM_DOMAIN_SUPPLIED: int
FLAG_NEGOTIATE_ANONYMOUS: int
FLAG_NEGOTIATE_NTLM: int
FLAG_NEGOTIATE_LM_KEY: int
FLAG_NEGOTIATE_DATAGRAM: int
FLAG_NEGOTIATE_SEAL: int
FLAG_NEGOTIATE_SIGN: int
FLAG_REQUEST_TARGET: int
FLAG_NEGOTIATE_OEM: int
FLAG_NEGOTIATE_UNICODE: int
FLAG_TYPES: Any
AV_END_OF_LIST: int
AV_NETBIOS_COMPUTER_NAME: int
AV_NETBIOS_DOMAIN_NAME: int
AV_DNS_COMPUTER_NAME: int
AV_DNS_DOMAIN_NAME: int
AV_DNS_TREE_NAME: int
AV_FLAGS: int
AV_TIMESTAMP: int
AV_SINGLE_HOST_DATA: int
AV_TARGET_NAME: int
AV_CHANNEL_BINDINGS: int
AV_TYPES: Any
AV_FLAG_CONSTRAINED: int
AV_FLAG_INTEGRITY: int
AV_FLAG_TARGET_SPN_UNTRUSTED: int
AV_FLAG_TYPES: Any

def pack_windows_version(debug: bool = False): ...
def unpack_windows_version(version_message): ...

class NtlmClient:
    client_config_flags: int
    exported_session_key: Any
    negotiated_flags: Any
    user_name: Any
    user_domain: Any
    no_lm_response_ntlm_v1: Any
    client_blocked: bool
    client_block_exceptions: Any
    client_require_128_bit_encryption: Any
    max_life_time: Any
    client_signing_key: Any
    client_sealing_key: Any
    sequence_number: Any
    server_sealing_key: Any
    server_signing_key: Any
    integrity: bool
    replay_detect: bool
    sequence_detect: bool
    confidentiality: bool
    datagram: bool
    identity: bool
    client_supplied_target_name: Any
    client_channel_binding_unhashed: Any
    unverified_target_name: Any
    server_challenge: Any
    server_target_name: Any
    server_target_info: Any
    server_version: Any
    server_av_netbios_computer_name: Any
    server_av_netbios_domain_name: Any
    server_av_dns_computer_name: Any
    server_av_dns_domain_name: Any
    server_av_dns_forest_name: Any
    server_av_target_name: Any
    server_av_flags: Any
    server_av_timestamp: Any
    server_av_single_host_data: Any
    server_av_channel_bindings: Any
    server_av_flag_constrained: Any
    server_av_flag_integrity: Any
    server_av_flag_target_spn_untrusted: Any
    current_encoding: Any
    client_challenge: Any
    server_target_info_raw: Any
    def __init__(self, domain, user_name, password) -> None: ...
    def get_client_flag(self, flag): ...
    def get_negotiated_flag(self, flag): ...
    def get_server_av_flag(self, flag): ...
    def set_client_flag(self, flags) -> None: ...
    def reset_client_flags(self) -> None: ...
    def unset_client_flag(self, flags) -> None: ...
    def create_negotiate_message(self): ...
    def parse_challenge_message(self, message): ...
    def create_authenticate_message(self): ...
    @staticmethod
    def pack_field(value, offset): ...
    @staticmethod
    def unpack_field(field_message): ...
    @staticmethod
    def unpack_av_info(info): ...
    @staticmethod
    def pack_av_info(avs): ...
    @staticmethod
    def pack_windows_timestamp(): ...
    def compute_nt_response(self): ...
    def ntowf_v2(self): ...



from _typeshed import StrPath, Unused
from typing import Literal, overload
from typing_extensions import TypeAlias
from xml.etree.ElementTree import ElementTree

from .Menu import Menu, MenuEntry, Separator, XMLMenuBuilder

_MenuItem: TypeAlias = Menu | MenuEntry | Separator

class MenuEditor:
    menu: Menu
    filename: str
    tree: ElementTree
    parser: XMLMenuBuilder
    filenames: list[str]
    def __init__(self, menu: Menu | None = None, filename: StrPath | None = None, root: bool = False) -> None: ...
    def parse(self, menu: Menu | None = None, filename: StrPath | None = None, root: bool = False) -> None: ...
    def save(self) -> None: ...

    # All "before" or "after" items can be one, the other, or neither, but not both.
    @overload
    def createMenuEntry(
        self,
        parent: Menu | None,
        name: str,
        command: str | None = None,
        genericname: str | None = None,
        comment: str | None = None,
        icon: str | None = None,
        terminal: bool | None = None,
        after: _MenuItem | None = None,
        before: None = None,
    ) -> MenuEntry: ...
    @overload
    def createMenuEntry(
        self,
        parent: Menu | None,
        name: str,
        command: str | None = None,
        genericname: str | None = None,
        comment: str | None = None,
        icon: str | None = None,
        terminal: bool | None = None,
        after: None = None,
        before: _MenuItem | None = None,
    ) -> MenuEntry: ...
    @overload
    def createMenu(
        self,
        parent: Menu | None,
        name: str,
        genericname: str | None = None,
        comment: str | None = None,
        icon: str | None = None,
        after: _MenuItem | None = None,
        before: None = None,
    ) -> Menu: ...
    @overload
    def createMenu(
        self,
        parent: Menu | None,
        name: str,
        genericname: str | None = None,
        comment: str | None = None,
        icon: str | None = None,
        after: None = None,
        before: _MenuItem | None = None,
    ) -> Menu: ...
    @overload
    def createSeparator(self, parent: Menu, after: _MenuItem | None = None, before: None = None) -> Separator: ...
    @overload
    def createSeparator(self, parent: Menu, after: None = None, before: _MenuItem | None = None) -> Separator: ...
    @overload
    def moveMenuEntry(
        self,
        menuentry: MenuEntry,
        oldparent: Menu | None,
        newparent: Menu | None,
        after: _MenuItem | None = None,
        before: None = None,
    ) -> MenuEntry: ...
    @overload
    def moveMenuEntry(
        self,
        menuentry: MenuEntry,
        oldparent: Menu | None,
        newparent: Menu | None,
        after: None = None,
        before: _MenuItem | None = None,
    ) -> MenuEntry: ...
    @overload
    def moveMenu(
        self, menu: Menu, oldparent: Menu, newparent: Menu, after: _MenuItem | None = None, before: None = None
    ) -> Menu: ...
    @overload
    def moveMenu(
        self, menu: Menu, oldparent: Menu, newparent: Menu, after: None = None, before: _MenuItem | None = None
    ) -> Menu: ...
    @overload
    def moveSeparator(
        self, separator: Separator, parent: Menu, after: _MenuItem | None = None, before: None = None
    ) -> Separator: ...
    @overload
    def moveSeparator(
        self, separator: Separator, parent: Menu, after: None = None, before: _MenuItem | None = None
    ) -> Separator: ...
    @overload
    def copyMenuEntry(
        self, menuentry: MenuEntry, oldparent: Unused, newparent: Menu, after: _MenuItem | None = None, before: None = None
    ) -> MenuEntry: ...
    @overload
    def copyMenuEntry(
        self, menuentry: MenuEntry, oldparent: Unused, newparent: Menu, after: None = None, before: _MenuItem | None = None
    ) -> MenuEntry: ...
    def editMenuEntry(
        self,
        menuentry: MenuEntry,
        name: str | None = None,
        genericname: str | None = None,
        comment: str | None = None,
        command: str | None = None,
        icon: str | None = None,
        terminal: bool | None = None,
        nodisplay: bool | None = None,
        hidden: bool | None = None,
    ) -> MenuEntry: ...
    def editMenu(
        self,
        menu: Menu,
        name: str | None = None,
        genericname: str | None = None,
        comment: str | None = None,
        icon: str | None = None,
        nodisplay: bool | None = None,
        hidden: bool | None = None,
    ) -> Menu: ...
    def hideMenuEntry(self, menuentry: MenuEntry) -> None: ...
    def unhideMenuEntry(self, menuentry: MenuEntry) -> None: ...
    def hideMenu(self, menu: Menu) -> None: ...
    def unhideMenu(self, menu: Menu) -> None: ...
    def deleteMenuEntry(self, menuentry: MenuEntry) -> MenuEntry: ...
    def revertMenuEntry(self, menuentry: MenuEntry) -> MenuEntry: ...
    def deleteMenu(self, menu: Menu) -> Menu: ...
    def revertMenu(self, menu: Menu) -> Menu: ...
    def deleteSeparator(self, separator: Separator) -> Separator: ...
    def getAction(self, entry: _MenuItem) -> Literal["none", "revert", "delete"]: ...



from _typeshed import Incomplete
from collections.abc import Generator

def cuthill_mckee_ordering(G, heuristic: Incomplete | None = None) -> Generator[Incomplete, Incomplete, None]: ...
def reverse_cuthill_mckee_ordering(G, heuristic: Incomplete | None = None): ...



from consolemenu.console_menu import ConsoleMenu
from consolemenu.items import ExternalItem as ExternalItem

class CommandItem(ExternalItem):
    command: str
    arguments: list[str]
    exit_status: int | None
    def __init__(
        self,
        text: str,
        command: str,
        arguments: list[str] | None = None,
        menu: ConsoleMenu | None = None,
        should_exit: bool = False,
        menu_char: str | None = None,
    ) -> None: ...
    def action(self) -> None: ...
    def get_return(self) -> int: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class SouthAfrica(WesternCalendar):
    include_good_friday: ClassVar[bool]
    include_christmas: ClassVar[bool]
    def holidays(self, year: Incomplete | None = None): ...
    def get_easter_monday_or_family_day(self, year): ...
    def get_fixed_holidays(self, year): ...
    def get_variable_days(self, year): ...
    def get_calendar_holidays(self, year): ...



from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class California(UnitedStates):
    include_thanksgiving_friday: ClassVar[bool]
    include_cesar_chavez_day: ClassVar[bool]
    include_columbus_day: ClassVar[bool]
    shift_exceptions: Incomplete
    def get_cesar_chavez_days(self, year): ...

class CaliforniaEducation(California):
    def get_variable_days(self, year): ...

class CaliforniaBerkeley(California):
    FIXED_HOLIDAYS: Incomplete
    include_cesar_chavez_day: ClassVar[bool]
    include_lincoln_birthday: ClassVar[bool]
    include_columbus_day: ClassVar[bool]
    columbus_day_label: ClassVar[str]

class CaliforniaSanFrancisco(California):
    include_cesar_chavez_day: ClassVar[bool]
    include_columbus_day: ClassVar[bool]

class CaliforniaWestHollywood(California):
    FIXED_HOLIDAYS: Incomplete
    include_cesar_chavez_day: ClassVar[bool]
    include_thanksgiving_friday: ClassVar[bool]



from _typeshed import ReadableBuffer
from typing import Any

from serial.serialutil import *

sab: Any  # IronPython object

def as_byte_array(string: bytes) -> Any: ...  # IronPython object

class Serial(SerialBase):
    def open(self) -> None: ...
    @property
    def in_waiting(self) -> int: ...
    def read(self, size: int = 1) -> bytes: ...
    def write(self, b: ReadableBuffer, /) -> int | None: ...
    def reset_input_buffer(self) -> None: ...
    def reset_output_buffer(self) -> None: ...
    @property
    def cts(self) -> bool: ...
    @property
    def dsr(self) -> bool: ...
    @property
    def ri(self) -> bool: ...
    @property
    def cd(self) -> bool: ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

class Aws(VaultApiBase):
    def configure_root_iam_credentials(
        self,
        access_key,
        secret_key,
        region: Incomplete | None = None,
        iam_endpoint: Incomplete | None = None,
        sts_endpoint: Incomplete | None = None,
        max_retries: Incomplete | None = None,
        mount_point="aws",
    ): ...
    def rotate_root_iam_credentials(self, mount_point="aws"): ...
    def configure_lease(self, lease, lease_max, mount_point="aws"): ...
    def read_lease_config(self, mount_point="aws"): ...
    def create_or_update_role(
        self,
        name,
        credential_type,
        policy_document: Incomplete | None = None,
        default_sts_ttl: Incomplete | None = None,
        max_sts_ttl: Incomplete | None = None,
        role_arns: Incomplete | None = None,
        policy_arns: Incomplete | None = None,
        legacy_params: bool = False,
        iam_tags: Incomplete | None = None,
        mount_point="aws",
    ): ...
    def read_role(self, name, mount_point="aws"): ...
    def list_roles(self, mount_point="aws"): ...
    def delete_role(self, name, mount_point="aws"): ...
    def generate_credentials(
        self,
        name,
        role_arn: Incomplete | None = None,
        ttl: Incomplete | None = None,
        endpoint: str = "creds",
        mount_point="aws",
        role_session_name: Incomplete | None = None,
    ): ...



from typing import ClassVar

from .core import UnitedStates

class Alabama(UnitedStates):
    include_confederation_day: ClassVar[bool]
    martin_luther_king_label: ClassVar[str]
    presidents_day_label: ClassVar[str]
    columbus_day_label: ClassVar[str]
    include_jefferson_davis_birthday: ClassVar[bool]

class AlabamaBaldwinCounty(Alabama):
    include_fat_tuesday: ClassVar[bool]

class AlabamaMobileCounty(Alabama):
    include_fat_tuesday: ClassVar[bool]

class AlabamaPerryCounty(Alabama):
    def get_obama_day(self, year): ...
    def get_variable_days(self, year): ...



from dataclasses import dataclass

from seaborn._marks.base import MappableColor, MappableFloat, MappableString, Mark, document_properties

@document_properties
@dataclass
class Text(Mark):
    text: MappableString = ...
    color: MappableColor = ...
    alpha: MappableFloat = ...
    fontsize: MappableFloat = ...
    halign: MappableString = ...
    valign: MappableString = ...
    offset: MappableFloat = ...



from boto.exception import BotoServerError

class InvalidGrantTokenException(BotoServerError): ...
class DisabledException(BotoServerError): ...
class LimitExceededException(BotoServerError): ...
class DependencyTimeoutException(BotoServerError): ...
class InvalidMarkerException(BotoServerError): ...
class AlreadyExistsException(BotoServerError): ...
class InvalidCiphertextException(BotoServerError): ...
class KeyUnavailableException(BotoServerError): ...
class InvalidAliasNameException(BotoServerError): ...
class UnsupportedOperationException(BotoServerError): ...
class InvalidArnException(BotoServerError): ...
class KMSInternalException(BotoServerError): ...
class InvalidKeyUsageException(BotoServerError): ...
class MalformedPolicyDocumentException(BotoServerError): ...
class NotFoundException(BotoServerError): ...



from typing_extensions import TypeAlias

import gdb

ContinueEventRegistry: TypeAlias = gdb.EventRegistry[gdb.ContinueEvent]

cont: ContinueEventRegistry

ExitedEventRegistry: TypeAlias = gdb.EventRegistry[gdb.ExitedEvent]

exited: ExitedEventRegistry

StopEventRegistry: TypeAlias = gdb.EventRegistry[gdb.StopEvent]

stop: StopEventRegistry

NewObjFileEventRegistry: TypeAlias = gdb.EventRegistry[gdb.NewObjFileEvent]

new_objfile: NewObjFileEventRegistry

ClearObjFilesEventRegistry: TypeAlias = gdb.EventRegistry[gdb.ClearObjFilesEvent]

clear_objfiles: ClearObjFilesEventRegistry

InferiorCallEventRegistry: TypeAlias = gdb.EventRegistry[gdb._InferiorCallEvent]

inferior_call: InferiorCallEventRegistry

MemoryChangedEventRegistry: TypeAlias = gdb.EventRegistry[gdb.MemoryChangedEvent]
memory_changed: MemoryChangedEventRegistry

RegisterChangedEventRegistry: TypeAlias = gdb.EventRegistry[gdb.RegisterChangedEvent]

register_changed: RegisterChangedEventRegistry

BreakpointEventRegistry: TypeAlias = gdb.EventRegistry[gdb.Breakpoint]

breakpoint_created: BreakpointEventRegistry
breakpoint_modified: BreakpointEventRegistry
breakpoint_deleted: BreakpointEventRegistry

BeforePromptEventRegistry: TypeAlias = gdb.EventRegistry[None]

before_prompt: BeforePromptEventRegistry

NewInferiorEventRegistry: TypeAlias = gdb.EventRegistry[gdb.NewInferiorEvent]

new_inferior: NewInferiorEventRegistry

InferiorDeletedEventRegistry: TypeAlias = gdb.EventRegistry[gdb.InferiorDeletedEvent]

inferior_deleted: InferiorDeletedEventRegistry

NewThreadEventRegistry: TypeAlias = gdb.EventRegistry[gdb.NewThreadEvent]

new_thread: NewThreadEventRegistry

GdbExitingEventRegistry: TypeAlias = gdb.EventRegistry[gdb.GdbExitingEvent]

gdb_exiting: GdbExitingEventRegistry

ConnectionEventRegistry: TypeAlias = gdb.EventRegistry[gdb.ConnectionEvent]

connection_removed: ConnectionEventRegistry



from _typeshed import Incomplete

from .context import Context as _Context

class AsyncContext(_Context):
    def __init__(self, *args, loop: Incomplete | None = None, use_task_factory: bool = True, **kwargs) -> None: ...
    def clear_trace_entities(self) -> None: ...

class TaskLocalStorage:
    def __init__(self, loop: Incomplete | None = None) -> None: ...
    def __setattr__(self, name: str, value) -> None: ...
    def __getattribute__(self, item: str): ...
    def clear(self) -> None: ...

def task_factory(loop, coro): ...



from _typeshed import Incomplete, Unused
from collections.abc import Callable, Iterable, Iterator, Mapping, MutableSequence
from typing import Any, ClassVar, NamedTuple, SupportsIndex, TypeVar, overload

_S = TypeVar("_S", bound=MutableSequence[str])

def strip_blank_lines(l: _S) -> _S: ...

class Reader:
    def __init__(self, data: str | list[str]) -> None: ...
    @overload
    def __getitem__(self, n: slice) -> list[str]: ...
    @overload
    def __getitem__(self, n: SupportsIndex) -> str: ...
    def reset(self) -> None: ...
    def read(self) -> str: ...
    def seek_next_non_empty_line(self) -> None: ...
    def eof(self) -> bool: ...
    def read_to_condition(self, condition_func: Callable[[str], bool]) -> list[str]: ...
    def read_to_next_empty_line(self) -> list[str]: ...
    def read_to_next_unindented_line(self) -> list[str]: ...
    def peek(self, n: int = 0) -> str: ...
    def is_empty(self) -> bool: ...

class ParseError(Exception): ...

class Parameter(NamedTuple):
    name: str
    type: str
    desc: list[str]

class NumpyDocString(Mapping[str, Any]):
    sections: ClassVar[dict[str, Any]]
    def __init__(self, docstring: str, config: Unused = {}) -> None: ...
    def __getitem__(self, key: str) -> Any: ...
    def __setitem__(self, key: str, val: Any) -> None: ...
    def __iter__(self) -> Iterator[str]: ...
    def __len__(self) -> int: ...
    empty_description: str

def indent(str: str | None, indent: int = 4) -> str: ...
def dedent_lines(lines: Iterable[str]) -> list[str]: ...
def header(text: str, style: str = "-") -> str: ...

class FunctionDoc(NumpyDocString):
    def __init__(self, func: object, role: str = "func", doc: str | None = None, config: Unused = {}) -> None: ...
    def get_func(self) -> tuple[Incomplete, str]: ...

class ClassDoc(NumpyDocString):
    extra_public_methods: list[str]
    show_inherited_members: bool
    @overload
    def __init__(
        self, cls: None, doc: str, modulename: str = "", func_doc: type[FunctionDoc] = ..., config: Mapping[str, Any] = {}
    ) -> None: ...
    @overload
    def __init__(
        self,
        cls: type,
        doc: str | None = None,
        modulename: str = "",
        func_doc: type[FunctionDoc] = ...,
        config: Mapping[str, Any] = {},
    ) -> None: ...
    @property
    def methods(self) -> list[str]: ...
    @property
    def properties(self) -> list[str]: ...



import _win32typing

def CreateEnvironmentBlock(Token: int, Inherit): ...
def DeleteProfile(SidString: str, ProfilePath: str | None = ..., ComputerName: str | None = ...) -> None: ...
def ExpandEnvironmentStringsForUser(Token: int, Src: str) -> str: ...
def GetAllUsersProfileDirectory() -> str: ...
def GetDefaultUserProfileDirectory() -> str: ...
def GetEnvironmentStrings(): ...
def GetProfilesDirectory() -> str: ...
def GetProfileType(): ...
def GetUserProfileDirectory(Token: int) -> str: ...
def LoadUserProfile(hToken: int, ProfileInfo: _win32typing.PyPROFILEINFO) -> _win32typing.PyHKEY: ...
def UnloadUserProfile(Token: int, Profile: _win32typing.PyHKEY) -> None: ...

PI_APPLYPOLICY: int
PI_NOUI: int
PT_MANDATORY: int
PT_ROAMING: int
PT_TEMPORARY: int



from typing import ClassVar

from .core import UnitedStates

class Delaware(UnitedStates):
    include_good_friday: ClassVar[bool]
    include_thanksgiving_friday: ClassVar[bool]
    include_federal_presidents_day: ClassVar[bool]
    include_columbus_day: ClassVar[bool]
    include_election_day_even: ClassVar[bool]



from _typeshed import Incomplete

from braintree.resource import Resource
from braintree.subscription import Subscription

class AndroidPayCard(Resource):
    is_expired: Incomplete
    subscriptions: list[Subscription]
    def __init__(self, gateway, attributes) -> None: ...
    @property
    def expiration_date(self): ...
    @property
    def last_4(self): ...
    @property
    def card_type(self): ...
    @staticmethod
    def signature(): ...
    @staticmethod
    def card_signature(): ...
    @staticmethod
    def network_token_signature(): ...



from collections.abc import Callable, Mapping
from datetime import datetime, tzinfo
from typing import IO, Any
from typing_extensions import TypeAlias

from .isoparser import isoparse as isoparse, isoparser as isoparser

_FileOrStr: TypeAlias = bytes | str | IO[str] | IO[Any]
_TzData: TypeAlias = tzinfo | int | str | None
_TzInfo: TypeAlias = Mapping[str, _TzData] | Callable[[str, int], _TzData]

class parserinfo:
    JUMP: list[str]
    WEEKDAYS: list[tuple[str, ...]]
    MONTHS: list[tuple[str, ...]]
    HMS: list[tuple[str, str, str]]
    AMPM: list[tuple[str, str]]
    UTCZONE: list[str]
    PERTAIN: list[str]
    TZOFFSET: dict[str, int]
    def __init__(self, dayfirst: bool = False, yearfirst: bool = False) -> None: ...
    def jump(self, name: str) -> bool: ...
    def weekday(self, name: str) -> int | None: ...
    def month(self, name: str) -> int | None: ...
    def hms(self, name: str) -> int | None: ...
    def ampm(self, name: str) -> int | None: ...
    def pertain(self, name: str) -> bool: ...
    def utczone(self, name: str) -> bool: ...
    def tzoffset(self, name: str) -> int | None: ...
    def convertyear(self, year: int) -> int: ...
    def validate(self, res: datetime) -> bool: ...

class parser:
    def __init__(self, info: parserinfo | None = None) -> None: ...
    def parse(
        self,
        timestr: _FileOrStr,
        default: datetime | None = None,
        ignoretz: bool = False,
        tzinfos: _TzInfo | None = None,
        *,
        dayfirst: bool | None = ...,
        yearfirst: bool | None = ...,
        fuzzy: bool = ...,
        fuzzy_with_tokens: bool = ...,
    ) -> datetime: ...

DEFAULTPARSER: parser

def parse(
    timestr: _FileOrStr,
    parserinfo: parserinfo | None = None,
    *,
    dayfirst: bool | None = ...,
    yearfirst: bool | None = ...,
    ignoretz: bool = ...,
    fuzzy: bool = ...,
    fuzzy_with_tokens: bool = ...,
    default: datetime | None = ...,
    tzinfos: _TzInfo | None = ...,
) -> datetime: ...

class _tzparser: ...

DEFAULTTZPARSER: _tzparser

class ParserError(ValueError): ...



from collections.abc import Callable

from consolemenu.menu_formatter import MenuFormatBuilder as MenuFormatBuilder
from consolemenu.screen import Screen as Screen

class ConsoleMenu:
    currently_active_menu: ConsoleMenu | None
    screen: Screen
    clear_screen_before_render: bool
    formatter: MenuFormatBuilder
    title: str | Callable[[], str] | None
    subtitle: str | Callable[[], str] | None
    prologue_text: str | Callable[[], str] | None
    epilogue_text: str | Callable[[], str] | None
    highlight: None
    normal: None
    show_exit_option: bool
    items: list[MenuItem]
    parent: ConsoleMenu | None
    exit_item: ExitItem
    current_option: int
    selected_option: int
    returned_value: object
    should_exit: bool
    previous_active_menu: ConsoleMenu | None
    def __init__(
        self,
        title: str | Callable[[], str] | None = None,
        subtitle: str | Callable[[], str] | None = None,
        screen: Screen | None = None,
        formatter: MenuFormatBuilder | None = None,
        prologue_text: str | Callable[[], str] | None = None,
        epilogue_text: str | Callable[[], str] | None = None,
        clear_screen: bool = True,
        show_exit_option: bool = True,
        exit_option_text: str = "Exit",
        exit_menu_char: str | None = None,
    ) -> None: ...
    @property
    def current_item(self) -> MenuItem | None: ...
    @property
    def selected_item(self) -> MenuItem | None: ...
    def append_item(self, item: MenuItem) -> None: ...
    def remove_item(self, item: MenuItem) -> bool: ...
    def add_exit(self) -> bool: ...
    def remove_exit(self) -> bool: ...
    def is_selected_item_exit(self) -> bool: ...
    def start(self, show_exit_option: bool | None = None) -> None: ...
    def show(self, show_exit_option: bool | None = None) -> None: ...
    def draw(self) -> None: ...
    def is_running(self) -> bool: ...
    def wait_for_start(self, timeout: float | None = None) -> bool: ...
    def is_alive(self) -> bool: ...
    def pause(self) -> None: ...
    def resume(self) -> None: ...
    def join(self, timeout: float | None = None) -> None: ...
    def get_input(self) -> int: ...
    def process_user_input(self) -> int | None: ...
    def go_to(self, option: int) -> None: ...
    def go_down(self) -> None: ...
    def go_up(self) -> None: ...
    def select(self) -> None: ...
    def exit(self) -> None: ...
    def clear_screen(self) -> None: ...
    def get_title(self) -> str: ...
    def get_subtitle(self) -> str: ...
    def get_prologue_text(self) -> str: ...
    def get_epilogue_text(self) -> str: ...

class MenuItem:
    text: str
    menu: ConsoleMenu | None
    should_exit: bool
    index_item_separator: str
    menu_char: str | None
    def __init__(
        self,
        text: str | Callable[[], str],
        menu: ConsoleMenu | None = None,
        should_exit: bool = False,
        menu_char: str | None = None,
    ) -> None: ...
    def show(self, index: int) -> str: ...
    def set_up(self) -> None: ...
    def action(self) -> None: ...
    def clean_up(self) -> None: ...
    def get_return(self) -> object: ...
    def __eq__(self, o: MenuItem) -> bool: ...  # type: ignore[override]
    def get_text(self) -> str: ...

class ExitItem(MenuItem):
    def __init__(
        self, text: str | Callable[[], str] = "Exit", menu: ConsoleMenu | None = None, menu_char: str | None = None
    ) -> None: ...
    def show(self, index: int, available_width: None = None) -> str: ...

def clear_terminal() -> None: ...



from _typeshed import Incomplete

class Token:
    INVALID_TYPE: int
    EPSILON: int
    MIN_USER_TOKEN_TYPE: int
    EOF: int
    DEFAULT_CHANNEL: int
    HIDDEN_CHANNEL: int
    source: Incomplete
    type: Incomplete
    channel: Incomplete
    start: Incomplete
    stop: Incomplete
    tokenIndex: Incomplete
    line: Incomplete
    column: Incomplete
    def __init__(self) -> None: ...
    @property
    def text(self): ...
    @text.setter
    def text(self, text: str): ...
    def getTokenSource(self): ...
    def getInputStream(self): ...

class CommonToken(Token):
    EMPTY_SOURCE: Incomplete
    source: Incomplete
    type: Incomplete
    channel: Incomplete
    start: Incomplete
    stop: Incomplete
    tokenIndex: int
    line: Incomplete
    column: Incomplete
    def __init__(
        self,
        source: tuple[Incomplete, Incomplete] = (None, None),
        type: int | None = None,
        channel: int = 0,
        start: int = -1,
        stop: int = -1,
    ) -> None: ...
    def clone(self): ...
    @property
    def text(self): ...
    @text.setter
    def text(self, text: str): ...



from _typeshed import Incomplete

from influxdb_client.domain.statement import Statement

class TestStatement(Statement):
    def __init__(self, type: Incomplete | None = None, assignment: Incomplete | None = None): ...
    @property
    def type(self): ...
    @type.setter
    def type(self, type) -> None: ...
    @property
    def assignment(self): ...
    @assignment.setter
    def assignment(self, assignment) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from typing import Any

class CompleteMultiPartUpload:
    bucket: Any
    location: Any
    bucket_name: Any
    key_name: Any
    etag: Any
    version_id: Any
    encrypted: Any
    def __init__(self, bucket: Incomplete | None = None) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...

class Part:
    bucket: Any
    part_number: Any
    last_modified: Any
    etag: Any
    size: Any
    def __init__(self, bucket: Incomplete | None = None) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...

def part_lister(mpupload, part_number_marker: Incomplete | None = None): ...

class MultiPartUpload:
    bucket: Any
    bucket_name: Any
    key_name: Any
    id: Any
    initiator: Any
    owner: Any
    storage_class: Any
    initiated: Any
    part_number_marker: Any
    next_part_number_marker: Any
    max_parts: Any
    is_truncated: bool
    def __init__(self, bucket: Incomplete | None = None) -> None: ...
    def __iter__(self): ...
    def to_xml(self): ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    def get_all_parts(
        self,
        max_parts: Incomplete | None = None,
        part_number_marker: Incomplete | None = None,
        encoding_type: Incomplete | None = None,
    ): ...
    def upload_part_from_file(
        self,
        fp,
        part_num,
        headers: Incomplete | None = None,
        replace: bool = True,
        cb: Incomplete | None = None,
        num_cb: int = 10,
        md5: Incomplete | None = None,
        size: Incomplete | None = None,
    ): ...
    def copy_part_from_key(
        self,
        src_bucket_name,
        src_key_name,
        part_num,
        start: Incomplete | None = None,
        end: Incomplete | None = None,
        src_version_id: Incomplete | None = None,
        headers: Incomplete | None = None,
    ): ...
    def complete_upload(self): ...
    def cancel_upload(self): ...



from Xlib.keysymdef import (
    apl as apl,
    arabic as arabic,
    cyrillic as cyrillic,
    greek as greek,
    hebrew as hebrew,
    katakana as katakana,
    korean as korean,
    latin1 as latin1,
    latin2 as latin2,
    latin3 as latin3,
    latin4 as latin4,
    miscellany as miscellany,
    publishing as publishing,
    special as special,
    technical as technical,
    thai as thai,
    xf86 as xf86,
    xk3270 as xk3270,
    xkb as xkb,
)

__all__ = [
    "apl",
    "arabic",
    "cyrillic",
    "greek",
    "hebrew",
    "katakana",
    "korean",
    "latin1",
    "latin2",
    "latin3",
    "latin4",
    "miscellany",
    "publishing",
    "special",
    "technical",
    "thai",
    "xf86",
    "xk3270",
    "xkb",
]



from _typeshed import Incomplete
from collections.abc import Mapping
from typing import Any

supports_lone_surrogates: bool

class MethodDispatcher(dict[Any, Any]):
    default: Any
    def __init__(self, items=()) -> None: ...
    def __getitem__(self, key): ...
    def __get__(self, instance, owner: Incomplete | None = None): ...

class BoundMethodDispatcher(Mapping[Any, Any]):
    instance: Any
    dispatcher: Any
    def __init__(self, instance, dispatcher) -> None: ...
    def __getitem__(self, key): ...
    def get(self, key, default): ...
    def __iter__(self): ...
    def __len__(self) -> int: ...
    def __contains__(self, key): ...

def isSurrogatePair(data): ...
def surrogatePairToCodepoint(data): ...
def moduleFactoryFactory(factory): ...



from _typeshed import Incomplete

from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Wrapping(SystemBackendMixin):
    def unwrap(self, token: Incomplete | None = None): ...



__all__ = ["STDOUT", "PIPE", "Wurlitzer", "pipes", "sys_pipes", "sys_pipes_forever", "stop_sys_pipes"]

import contextlib
import io
from _typeshed import SupportsWrite
from contextlib import _GeneratorContextManager
from types import TracebackType
from typing import Any, Final, Literal, Protocol, TextIO, TypeVar, overload
from typing_extensions import TypeAlias

STDOUT: Final = 2
PIPE: Final = 3
_STDOUT: TypeAlias = Literal[2]
_PIPE: TypeAlias = Literal[3]
_T_contra = TypeVar("_T_contra", contravariant=True)
_StreamOutT = TypeVar("_StreamOutT", bound=_Stream[str] | _Stream[bytes])
_StreamErrT = TypeVar("_StreamErrT", bound=_Stream[str] | _Stream[bytes])

class _Stream(SupportsWrite[_T_contra], Protocol):
    def seek(self, offset: int, whence: int = ..., /) -> int: ...

# Alias for IPython.core.interactiveshell.InteractiveShell.
# N.B. Even if we added ipython to the stub-uploader allowlist,
# we wouldn't be able to declare a dependency on ipython here,
# since `wurlitzer` does not declare a dependency on `ipython` at runtime
_InteractiveShell: TypeAlias = Any

class Wurlitzer:
    flush_interval: float
    encoding: str | None

    def __init__(
        self,
        stdout: SupportsWrite[str] | SupportsWrite[bytes] | None = None,
        stderr: _STDOUT | SupportsWrite[str] | SupportsWrite[bytes] | None = None,
        encoding: str | None = ...,
        bufsize: int | None = ...,
    ) -> None: ...
    def __enter__(self): ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None
    ) -> None: ...

def dup2(a: int, b: int, timeout: float = 3) -> int: ...
def sys_pipes(encoding: str = ..., bufsize: int | None = None) -> contextlib._GeneratorContextManager[tuple[TextIO, TextIO]]: ...

# stubtest does not support overloaded context managers, hence the _GeneratorContextManager[Foo] return types.
@overload
def pipes(
    stdout: _PIPE, stderr: _STDOUT, encoding: None, bufsize: int | None = None
) -> _GeneratorContextManager[tuple[io.BytesIO, None]]: ...
@overload
def pipes(
    stdout: _PIPE, stderr: _PIPE, encoding: None, bufsize: int | None = None
) -> _GeneratorContextManager[tuple[io.BytesIO, io.BytesIO]]: ...
@overload
def pipes(
    stdout: _PIPE, stderr: _StreamErrT, encoding: None, bufsize: int | None = None
) -> _GeneratorContextManager[tuple[io.BytesIO, _StreamErrT]]: ...
@overload
def pipes(
    stdout: _PIPE, stderr: _STDOUT, encoding: str = ..., bufsize: int | None = None
) -> _GeneratorContextManager[tuple[io.StringIO, None]]: ...
@overload
def pipes(
    stdout: _PIPE, stderr: _PIPE, encoding: str = ..., bufsize: int | None = None
) -> _GeneratorContextManager[tuple[io.StringIO, io.StringIO]]: ...
@overload
def pipes(
    stdout: _PIPE, stderr: _StreamErrT, encoding: str = ..., bufsize: int | None = None
) -> _GeneratorContextManager[tuple[io.StringIO, _StreamErrT]]: ...
@overload
def pipes(
    stdout: _StreamOutT, stderr: _STDOUT, encoding: str | None = ..., bufsize: int | None = None
) -> _GeneratorContextManager[tuple[_StreamOutT, None]]: ...
@overload
def pipes(
    stdout: _StreamOutT, stderr: _PIPE, encoding: None, bufsize: int | None = None
) -> _GeneratorContextManager[tuple[_StreamOutT, io.BytesIO]]: ...
@overload
def pipes(
    stdout: _StreamOutT, stderr: _PIPE, encoding: str = ..., bufsize: int | None = None
) -> _GeneratorContextManager[tuple[_StreamOutT, io.StringIO]]: ...
@overload
def pipes(
    stdout: _StreamOutT, stderr: _StreamErrT, encoding: str | None = ..., bufsize: int | None = None
) -> _GeneratorContextManager[tuple[_StreamOutT, _StreamErrT]]: ...
@overload
def pipes(
    stdout: _PIPE | _StreamOutT = 3,
    stderr: _STDOUT | _PIPE | _StreamErrT = 3,
    encoding: str | None = ...,
    bufsize: int | None = None,
) -> _GeneratorContextManager[tuple[io.BytesIO | io.StringIO | _StreamOutT, io.BytesIO | io.StringIO | _StreamErrT | None]]: ...
def sys_pipes_forever(encoding: str = ..., bufsize: int | None = None) -> None: ...
def stop_sys_pipes() -> None: ...
def load_ipython_extension(ip: _InteractiveShell) -> None: ...
def unload_ipython_extension(ip: _InteractiveShell) -> None: ...



from consolemenu.validators.base import BaseValidator as BaseValidator

class RegexValidator(BaseValidator):
    def __init__(self, pattern: str) -> None: ...
    @property
    def pattern(self) -> str: ...
    def validate(self, input_string: str) -> bool: ...



from collections.abc import Sequence

def namedtuple(typename: str, field_names: Sequence[str], verbose: bool = False, rename: bool = False): ...
def namedlist(typename: str, field_names: Sequence[str], verbose: bool = False, rename: bool = False): ...



from _typeshed import Incomplete
from typing import Any

baseChar: str
ideographic: str
combiningCharacter: str
digit: str
extender: str
letter: Any
name: Any
nameFirst: Any
reChar: Any
reCharRange: Any

def charStringToList(chars): ...
def normaliseCharList(charList): ...

max_unicode: Any

def missingRanges(charList): ...
def listToRegexpStr(charList): ...
def hexToInt(hex_str): ...
def escapeRegexp(string): ...

nonXmlNameBMPRegexp: Any
nonXmlNameFirstBMPRegexp: Any
nonPubidCharRegexp: Any

class InfosetFilter:
    replacementRegexp: Any
    dropXmlnsLocalName: Any
    dropXmlnsAttrNs: Any
    preventDoubleDashComments: Any
    preventDashAtCommentEnd: Any
    replaceFormFeedCharacters: Any
    preventSingleQuotePubid: Any
    replaceCache: Any
    def __init__(
        self,
        dropXmlnsLocalName: bool = False,
        dropXmlnsAttrNs: bool = False,
        preventDoubleDashComments: bool = False,
        preventDashAtCommentEnd: bool = False,
        replaceFormFeedCharacters: bool = True,
        preventSingleQuotePubid: bool = False,
    ) -> None: ...
    def coerceAttribute(self, name, namespace: Incomplete | None = None): ...
    def coerceElement(self, name): ...
    def coerceComment(self, data): ...
    def coerceCharacters(self, data): ...
    def coercePubid(self, data): ...
    def toXmlName(self, name): ...
    def getReplacementCharacter(self, char): ...
    def fromXmlName(self, name): ...
    def escapeChar(self, char): ...
    def unescapeChar(self, charcode): ...



from _typeshed import Incomplete

class OnboardingResponse:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        user: Incomplete | None = None,
        org: Incomplete | None = None,
        bucket: Incomplete | None = None,
        auth: Incomplete | None = None,
    ) -> None: ...
    @property
    def user(self): ...
    @user.setter
    def user(self, user) -> None: ...
    @property
    def org(self): ...
    @org.setter
    def org(self, org) -> None: ...
    @property
    def bucket(self): ...
    @bucket.setter
    def bucket(self, bucket) -> None: ...
    @property
    def auth(self): ...
    @auth.setter
    def auth(self, auth) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from collections.abc import Generator, Iterable
from typing import Literal, TypeVar, overload

from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatch

_U = TypeVar("_U")

@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None = None,
    data: Literal[False] = False,
    keys: Literal[False] = False,
    default=None,
) -> Generator[tuple[_Node, _Node], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None,
    data: Literal[True],
    keys: Literal[False] = False,
    default=None,
) -> Generator[tuple[_Node, _Node, dict[str, Incomplete]], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None = None,
    *,
    data: Literal[True],
    keys: Literal[False] = False,
    default=None,
) -> Generator[tuple[_Node, _Node, dict[str, Incomplete]], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None,
    data: str,
    keys: Literal[False] = False,
    default: _U | None = None,
) -> Generator[tuple[_Node, _Node, dict[str, _U]], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None = None,
    *,
    data: str,
    keys: Literal[False] = False,
    default: _U | None = None,
) -> Generator[tuple[_Node, _Node, dict[str, _U]], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None,
    data: Literal[False],
    keys: Literal[True],
    default=None,
) -> Generator[tuple[_Node, _Node, int], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None = None,
    data: Literal[False] = False,
    *,
    keys: Literal[True],
    default=None,
) -> Generator[tuple[_Node, _Node, int], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None,
    data: Literal[True],
    keys: Literal[True],
    default=None,
) -> Generator[tuple[_Node, _Node, int, dict[str, Incomplete]], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None = None,
    *,
    data: Literal[True],
    keys: Literal[True],
    default=None,
) -> Generator[tuple[_Node, _Node, int, dict[str, Incomplete]], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None,
    data: str,
    keys: Literal[True],
    default: _U | None = None,
) -> Generator[tuple[_Node, _Node, int, dict[str, _U]], None, None]: ...
@overload
def edge_boundary(
    G: Graph[_Node],
    nbunch1: Iterable[_Node],
    nbunch2: Iterable[_Node] | None = None,
    *,
    data: str,
    keys: Literal[True],
    default: _U | None = None,
) -> Generator[tuple[_Node, _Node, int, dict[str, _U]], None, None]: ...
@_dispatch
def node_boundary(G: Graph[_Node], nbunch1: Iterable[_Node], nbunch2: Iterable[_Node] | None = None) -> set[_Node]: ...



import ssl
from collections.abc import Iterable
from typing import TypedDict
from typing_extensions import NotRequired, TypeAlias

_Payload: TypeAlias = str | bytes | bytearray | float

class _Msg(TypedDict):
    topic: str
    payload: NotRequired[_Payload | None]
    qos: NotRequired[int]
    retain: NotRequired[int]

class _Auth(TypedDict):
    username: str
    password: NotRequired[str]

class _TLS(TypedDict):
    ca_certs: str
    certfile: NotRequired[str]
    keyfile: NotRequired[str]
    tls_version: NotRequired[ssl._SSLMethod]
    ciphers: NotRequired[str]
    insecure: NotRequired[str]
    cert_reqs: NotRequired[ssl.VerifyMode]
    keyfile_password: NotRequired[ssl._PasswordType]

class _Proxy(TypedDict):
    proxy_type: int
    proxy_addr: str
    proxy_rdns: NotRequired[bool]
    proxy_username: NotRequired[str]
    proxy_passwor: NotRequired[str]

def multiple(
    msgs: Iterable[_Msg],
    hostname: str = "localhost",
    port: int = 1883,
    client_id: str = "",
    keepalive: int = 60,
    will: _Msg | None = None,
    auth: _Auth | None = None,
    tls: _TLS | None = None,
    protocol: int = 4,
    transport: str = "tcp",
    proxy_args: _Proxy | None = None,
) -> None: ...
def single(
    topic: str,
    payload: _Payload | None = None,
    qos: int | None = 0,
    retain: bool | None = False,
    hostname: str = "localhost",
    port: int = 1883,
    client_id: str = "",
    keepalive: int = 60,
    will: _Msg | None = None,
    auth: _Auth | None = None,
    tls: _TLS | None = None,
    protocol: int = 4,
    transport: str = "tcp",
    proxy_args: _Proxy | None = None,
) -> None: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def astar_path(G, source, target, heuristic: Incomplete | None = None, weight: str = "weight"): ...
@_dispatch
def astar_path_length(G, source, target, heuristic: Incomplete | None = None, weight: str = "weight"): ...



from _typeshed import Incomplete, Unused
from collections.abc import Generator
from typing import ClassVar, Literal, TypeVar, overload
from zipfile import ZipFile

from openpyxl.descriptors.base import Alias, String
from openpyxl.descriptors.serialisable import Serialisable
from openpyxl.pivot.cache import CacheDefinition
from openpyxl.pivot.record import RecordList
from openpyxl.pivot.table import TableDefinition
from openpyxl.xml.functions import Element

_SerialisableT = TypeVar("_SerialisableT", bound=Serialisable)
_SerialisableRelTypeT = TypeVar("_SerialisableRelTypeT", bound=CacheDefinition | RecordList | TableDefinition)

class Relationship(Serialisable):
    tagname: ClassVar[str]
    Type: String[Literal[False]]
    Target: String[Literal[False]]
    target: Alias
    TargetMode: String[Literal[True]]
    Id: String[Literal[True]]
    id: Alias
    @overload
    def __init__(
        self, Id: str, Type: Unused = None, *, type: str, Target: str | None = None, TargetMode: str | None = None
    ) -> None: ...
    @overload
    def __init__(self, Id: str, Type: Unused, type: str, Target: str | None = None, TargetMode: str | None = None) -> None: ...
    @overload
    def __init__(
        self, Id: str, Type: str, type: None = None, Target: str | None = None, TargetMode: str | None = None
    ) -> None: ...

class RelationshipList(Serialisable):
    tagname: ClassVar[str]
    Relationship: Incomplete
    def __init__(self, Relationship=()) -> None: ...
    def append(self, value) -> None: ...
    def __len__(self) -> int: ...
    def __bool__(self) -> bool: ...
    def find(self, content_type) -> Generator[Incomplete, None, None]: ...
    def __getitem__(self, key): ...
    def to_tree(self) -> Element: ...  # type: ignore[override]

def get_rels_path(path): ...
def get_dependents(archive: ZipFile, filename: str) -> RelationshipList: ...

# If `id` is None, `cls` needs to have ClassVar `rel_type`.
# The `deps` attribute used at runtime is for internal use immediately after the return.
# `cls` cannot be None
@overload
def get_rel(
    archive: ZipFile, deps: RelationshipList, id: None = None, *, cls: type[_SerialisableRelTypeT]
) -> _SerialisableRelTypeT | None: ...
@overload
def get_rel(
    archive: ZipFile, deps: RelationshipList, id: None, cls: type[_SerialisableRelTypeT]
) -> _SerialisableRelTypeT | None: ...
@overload
def get_rel(archive: ZipFile, deps: RelationshipList, id: str, cls: type[_SerialisableT]) -> _SerialisableT: ...



import sys
from contextvars import Context
from types import TracebackType
from typing import Any, TypeVar
from typing_extensions import Self

from . import _CoroutineLike
from .events import AbstractEventLoop
from .tasks import Task

if sys.version_info >= (3, 12):
    __all__ = ("TaskGroup",)
else:
    __all__ = ["TaskGroup"]

_T = TypeVar("_T")

class TaskGroup:
    _loop: AbstractEventLoop | None
    _tasks: set[Task[Any]]

    async def __aenter__(self) -> Self: ...
    async def __aexit__(self, et: type[BaseException] | None, exc: BaseException | None, tb: TracebackType | None) -> None: ...
    def create_task(self, coro: _CoroutineLike[_T], *, name: str | None = None, context: Context | None = None) -> Task[_T]: ...
    def _on_task_done(self, task: Task[object]) -> None: ...



from _typeshed import sentinel
from _typeshed.wsgi import WSGIEnvironment
from collections.abc import Callable, Collection, ItemsView, Iterator, KeysView, MutableMapping, ValuesView
from datetime import date, datetime, timedelta
from hashlib import _Hash
from typing import Any, Literal, Protocol, TypeVar, overload
from typing_extensions import TypeAlias

from webob.descriptors import _AsymmetricProperty
from webob.request import Request
from webob.response import Response

_T = TypeVar("_T")
# we accept both the official spelling and the one used in the WebOb docs
# the implementation compares after lower() so technically there are more
# valid spellings, but it seems more natural to support these two spellings
_SameSitePolicy: TypeAlias = Literal["Strict", "Lax", "None", "strict", "lax", "none"]

class _Serializer(Protocol):
    def loads(self, appstruct: Any, /) -> bytes: ...
    def dumps(self, bstruct: bytes, /) -> Any: ...

class RequestCookies(MutableMapping[str, str]):
    def __init__(self, environ: WSGIEnvironment) -> None: ...
    def __setitem__(self, name: str, value: str) -> None: ...
    def __getitem__(self, name: str) -> str: ...
    @overload
    def get(self, name: str, default: None = None) -> str | None: ...
    @overload
    def get(self, name: str, default: str | _T) -> str | _T: ...
    def __delitem__(self, name: str) -> None: ...
    def keys(self) -> KeysView[str]: ...
    def values(self) -> ValuesView[str]: ...
    def items(self) -> ItemsView[str, str]: ...
    def __contains__(self, name: object) -> bool: ...
    def __iter__(self) -> Iterator[str]: ...
    def __len__(self) -> int: ...
    def clear(self) -> None: ...

class Cookie(dict[str, Morsel]):
    def __init__(self, input: str | None = None) -> None: ...
    def load(self, data: str) -> None: ...
    def add(self, key: str | bytes, val: str | bytes) -> Morsel: ...
    def __setitem__(self, key: str | bytes, val: str | bytes) -> Morsel: ...  # type: ignore[override]
    def serialize(self, full: bool = True) -> str: ...
    def values(self) -> list[Morsel]: ...  # type: ignore[override]
    def __str__(self, full: bool = True) -> str: ...

class Morsel(dict[bytes, bytes | bool | None]):
    name: bytes
    value: bytes
    def __init__(self, name: str | bytes, value: str | bytes) -> None: ...
    @property
    def path(self) -> bytes | None: ...
    @path.setter
    def path(self, v: bytes | None) -> None: ...
    @property
    def domain(self) -> bytes | None: ...
    @domain.setter
    def domain(self, v: bytes | None) -> None: ...
    @property
    def comment(self) -> bytes | None: ...
    @comment.setter
    def comment(self, v: bytes | None) -> None: ...
    expires: _AsymmetricProperty[bytes | None, datetime | date | timedelta | int | str | bytes | None]
    max_age: _AsymmetricProperty[bytes | None, timedelta | int | str | bytes]
    @property
    def httponly(self) -> bool | None: ...
    @httponly.setter
    def httponly(self, v: bool) -> None: ...
    @property
    def secure(self) -> bool | None: ...
    @secure.setter
    def secure(self, v: bool) -> None: ...
    samesite: _AsymmetricProperty[bytes | None, _SameSitePolicy | None]
    def serialize(self, full: bool = True) -> str: ...
    def __str__(self, full: bool = True) -> str: ...

def make_cookie(
    name: str | bytes,
    value: str | bytes | None,
    max_age: int | timedelta | None = None,
    path: str = "/",
    domain: str | None = None,
    secure: bool = False,
    httponly: bool = False,
    comment: str | None = None,
    samesite: _SameSitePolicy | None = None,
) -> str: ...

class JSONSerializer:
    def dumps(self, appstruct: Any) -> bytes: ...
    def loads(self, bstruct: bytes | str) -> Any: ...

class Base64Serializer:
    serializer: _Serializer
    def __init__(self, serializer: _Serializer | None = None) -> None: ...
    def dumps(self, appstruct: Any) -> bytes: ...
    def loads(self, bstruct: bytes) -> Any: ...

class SignedSerializer:
    salt: str
    secret: str
    hashalg: str
    salted_secret: bytes
    digestmod: Callable[[bytes], _Hash]
    digest_size: int
    serializer: _Serializer
    def __init__(self, secret: str, salt: str, hashalg: str = "sha512", serializer: _Serializer | None = None) -> None: ...
    def dumps(self, appstruct: Any) -> bytes: ...
    def loads(self, bstruct: bytes) -> Any: ...

class CookieProfile:
    cookie_name: str
    secure: bool
    max_age: int | timedelta | None
    httponly: bool | None
    samesite: _SameSitePolicy | None
    path: str
    domains: Collection[str] | None
    serializer: _Serializer
    request: Request | None
    def __init__(
        self,
        cookie_name: str,
        secure: bool = False,
        max_age: int | timedelta | None = None,
        httponly: bool | None = None,
        samesite: _SameSitePolicy | None = None,
        path: str = "/",
        # even though the docs claim any iterable is fine, that is
        # clearly not the case judging by the implementation
        domains: Collection[str] | None = None,
        serializer: _Serializer | None = None,
    ) -> None: ...
    def __call__(self, request: Request) -> CookieProfile: ...
    def bind(self, request: Request) -> CookieProfile: ...
    def get_value(self) -> Any | None: ...
    def set_cookies(
        self,
        response: Response,
        value: Any,
        domains: Collection[str] = sentinel,
        max_age: int | timedelta | None = sentinel,
        path: str = sentinel,
        secure: bool = sentinel,
        httponly: bool = sentinel,
        samesite: _SameSitePolicy | None = sentinel,
    ) -> Response: ...
    def get_headers(
        self,
        value: Any,
        domains: Collection[str] = sentinel,
        max_age: int | timedelta | None = sentinel,
        path: str = sentinel,
        secure: bool = sentinel,
        httponly: bool = sentinel,
        samesite: _SameSitePolicy | None = sentinel,
    ) -> list[tuple[str, str]]: ...

class SignedCookieProfile(CookieProfile):
    secret: str
    salt: str
    hashalg: str
    serializer: SignedSerializer
    original_serializer: _Serializer
    def __init__(
        self,
        secret: str,
        salt: str,
        cookie_name: str,
        secure: bool = False,
        max_age: int | timedelta | None = None,
        httponly: bool = False,
        samesite: _SameSitePolicy | None = None,
        path: str = "/",
        domains: Collection[str] | None = None,
        hashalg: str = "sha512",
        serializer: _Serializer | None = None,
    ) -> None: ...
    def __call__(self, request: Request) -> SignedCookieProfile: ...
    def bind(self, request: Request) -> SignedCookieProfile: ...



from _typeshed import Incomplete

class CustomerGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def all(self): ...
    def create(self, params: Incomplete | None = None): ...
    def delete(self, customer_id): ...
    def find(self, customer_id, association_filter_id: Incomplete | None = None): ...
    def search(self, *query): ...
    def update(self, customer_id, params: Incomplete | None = None): ...



from .autumn_holiday import (
    AutumnHolidayFirstMondayOctober as AutumnHolidayFirstMondayOctober,
    AutumnHolidayLastMondaySeptember as AutumnHolidayLastMondaySeptember,
    AutumnHolidaySecondMondayOctober as AutumnHolidaySecondMondayOctober,
    AutumnHolidayThirdMondayOctober as AutumnHolidayThirdMondayOctober,
)
from .fair_holiday import (
    FairHolidayFirstMondayAugust as FairHolidayFirstMondayAugust,
    FairHolidayFirstMondayJuly as FairHolidayFirstMondayJuly,
    FairHolidayFourthFridayJuly as FairHolidayFourthFridayJuly,
    FairHolidayLastMondayJuly as FairHolidayLastMondayJuly,
    FairHolidayLastMondayJune as FairHolidayLastMondayJune,
    FairHolidaySecondMondayJuly as FairHolidaySecondMondayJuly,
    FairHolidayThirdMondayJuly as FairHolidayThirdMondayJuly,
)
from .spring_holiday import (
    SpringHolidayFirstMondayApril as SpringHolidayFirstMondayApril,
    SpringHolidayFirstMondayJune as SpringHolidayFirstMondayJune,
    SpringHolidayLastMondayMay as SpringHolidayLastMondayMay,
    SpringHolidaySecondMondayApril as SpringHolidaySecondMondayApril,
    SpringHolidayTuesdayAfterFirstMondayMay as SpringHolidayTuesdayAfterFirstMondayMay,
)
from .victoria_day import (
    VictoriaDayFirstMondayJune as VictoriaDayFirstMondayJune,
    VictoriaDayFourthMondayMay as VictoriaDayFourthMondayMay,
    VictoriaDayLastMondayMay as VictoriaDayLastMondayMay,
)

class LateSummer:
    def get_variable_days(self, year): ...

class BattleStirlingBridge:
    def get_variable_days(self, year): ...

class AyrGoldCup:
    def get_variable_days(self, year): ...

# Names in __all__ with no definition:
#   VictoriaDayTuesdayAfterFirstMondayMay



from _typeshed import SupportsKeysAndGetItem, Unused
from collections.abc import Iterable
from typing import Final, Literal, NoReturn, overload
from typing_extensions import Self, TypeAlias

from .util import AbstractKeystore, AbstractKeystoreEntry

__version_info__: Final[tuple[int, int, int] | tuple[int, int, int, str]]
__version__: Final[str]
MAGIC_NUMBER_JKS: Final[bytes]
MAGIC_NUMBER_JCEKS: Final[bytes]
SIGNATURE_WHITENING: Final[bytes]

_JksType: TypeAlias = Literal["jks", "jceks"]
_CertType: TypeAlias = Literal["X.509"]
_KeyFormat: TypeAlias = Literal["pkcs8", "rsa_raw"]

class TrustedCertEntry(AbstractKeystoreEntry):
    store_type: _JksType | None
    type: _CertType | None
    cert: bytes
    # NB! For most use cases, use TrustedCertEntry.new() classmethod.
    def __init__(
        self,
        *,
        type: _CertType | None = None,
        cert: bytes,
        store_type: _JksType | None = None,
        alias: str,
        timestamp: int,
        **kwargs: Unused,
    ) -> None: ...
    @classmethod
    def new(cls, alias: str, cert: bytes) -> Self: ...  # type: ignore[override]
    def is_decrypted(self) -> Literal[True]: ...

class PrivateKeyEntry(AbstractKeystoreEntry):
    store_type: _JksType | None
    cert_chain: list[tuple[_CertType, bytes]]
    # Properties provided by __getattr__ after decryption
    @property
    def pkey(self) -> bytes: ...
    @property
    def pkey_pkcs8(self) -> bytes: ...
    @property
    def algorithm_oid(self) -> tuple[int, ...]: ...
    # NB! For most use cases, use PrivateKeyEntry.new() classmethod.
    # Overloaded: must provide `encrypted` OR `pkey`, `pkey_pkcs8`, `algorithm_oid`
    @overload
    def __init__(
        self,
        *,
        cert_chain: list[tuple[_CertType, bytes]],
        encrypted: bytes,
        store_type: _JksType | None = None,
        alias: str,
        timestamp: int,
        **kwargs: Unused,
    ) -> None: ...
    @overload
    def __init__(
        self,
        *,
        cert_chain: list[tuple[_CertType, bytes]],
        pkey: bytes,
        pkey_pkcs8: bytes,
        algorithm_oid: tuple[int, ...],
        store_type: _JksType | None = None,
        alias: str,
        timestamp: int,
        **kwargs: Unused,
    ) -> None: ...
    @classmethod
    def new(  # type: ignore[override]
        cls, alias: str, certs: Iterable[bytes], key: bytes, key_format: _KeyFormat = "pkcs8"
    ) -> Self: ...

class SecretKeyEntry(AbstractKeystoreEntry):
    store_type: _JksType | None
    # Properties provided by __getattr__
    @property
    def algorithm(self) -> str: ...
    @property
    def key(self) -> bytes: ...
    @property
    def key_size(self) -> int: ...
    # Overloaded: must provide `sealed_obj` OR `algorithm`, `key`, `key_size`
    @overload
    def __init__(
        self, *, sealed_obj: bytes, store_type: _JksType | None = None, alias: str, timestamp: int, **kwargs: Unused
    ) -> None: ...
    @overload
    def __init__(
        self,
        *,
        algorithm: str,
        key: bytes,
        key_size: int,
        store_type: _JksType | None = None,
        alias: str,
        timestamp: int,
        **kwargs: Unused,
    ) -> None: ...
    # Not implemented by pyjks
    @classmethod
    def new(  # type: ignore[override]
        cls, alias: str, sealed_obj: bool, algorithm: str, key: bytes, key_size: int
    ) -> NoReturn: ...
    # Not implemented by pyjks
    def encrypt(self, key_password: str) -> NoReturn: ...

class KeyStore(AbstractKeystore):
    entries: dict[str, TrustedCertEntry | PrivateKeyEntry | SecretKeyEntry]  # type: ignore[assignment]
    store_type: _JksType
    @classmethod
    def new(cls, store_type: _JksType, store_entries: Iterable[TrustedCertEntry | PrivateKeyEntry | SecretKeyEntry]) -> Self: ...
    @classmethod
    def loads(cls, data: bytes, store_password: str | None, try_decrypt_keys: bool = True) -> Self: ...
    def saves(self, store_password: str) -> bytes: ...
    # NB! For most use cases, use KeyStore.new() classmethod.
    def __init__(
        self, store_type: _JksType, entries: SupportsKeysAndGetItem[str, TrustedCertEntry | PrivateKeyEntry | SecretKeyEntry]
    ) -> None: ...
    @property
    def certs(self) -> dict[str, TrustedCertEntry]: ...
    @property
    def secret_keys(self) -> dict[str, SecretKeyEntry]: ...
    @property
    def private_keys(self) -> dict[str, PrivateKeyEntry]: ...



from influxdb_client import Organization

class OrganizationsApi:
    def __init__(self, influxdb_client) -> None: ...
    def me(self): ...
    def find_organization(self, org_id): ...
    def find_organizations(self, **kwargs): ...
    def create_organization(self, name: str | None = None, organization: Organization | None = None) -> Organization: ...
    def update_organization(self, organization: Organization) -> Organization: ...
    def delete_organization(self, org_id: str): ...



from _typeshed import FileDescriptorOrPath
from asyncio.events import AbstractEventLoop
from collections.abc import Awaitable, Callable
from typing import Any, TypeVar

_R = TypeVar("_R")

def wrap(func: Callable[..., _R]) -> Callable[..., Awaitable[_R]]: ...
async def exists(path: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> bool: ...
async def isfile(path: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> bool: ...
async def isdir(s: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> bool: ...
async def getsize(filename: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> int: ...
async def getmtime(filename: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> float: ...
async def getatime(filename: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> float: ...
async def getctime(filename: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> float: ...
async def samefile(
    f1: FileDescriptorOrPath, f2: FileDescriptorOrPath, *, loop: AbstractEventLoop | None = ..., executor: Any = ...
) -> bool: ...
async def sameopenfile(fp1: int, fp2: int, *, loop: AbstractEventLoop | None = ..., executor: Any = ...) -> bool: ...
async def islink(path: FileDescriptorOrPath) -> bool: ...
async def ismount(path: FileDescriptorOrPath) -> bool: ...



from _typeshed import Incomplete
from collections.abc import Generator

class ResourceCollection:
    def __init__(self, query, results, method) -> None: ...
    @property
    def maximum_size(self): ...
    @property
    def first(self): ...
    @property
    def items(self) -> Generator[Incomplete, None, None]: ...
    @property
    def ids(self): ...
    def __iter__(self): ...



from typing import ClassVar, Literal

from . import ImageFile
from ._imaging import _PixelAccessor

class WalImageFile(ImageFile.ImageFile):
    format: ClassVar[Literal["WAL"]]
    format_description: ClassVar[str]
    def load(self) -> _PixelAccessor: ...

def open(filename): ...

quake2palette: bytes
